# -*- coding: utf-8 -*-

# Resource object code
#
# Created: qui dez 13 17:14:04 2018
#      by: The Resource Compiler for PySide (Qt v4.8.4)
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore

qt_resource_data = b"\x00\x00\xa2\xe6/* QDarkStyleSheet --------------------------------------------------------\x0a\x0aThis is the main style sheet, the palette has nine main colors.\x0aIt is based on three selecting colors, three greyish (background) colors\x0aplus three whitish (foreground) colors. Each set of widgets of the same\x0atype have a header like this:\x0a\x0a    ------------------\x0a    GroupName --------\x0a    ------------------\x0a\x0aAnd each widget is separated with a header like this:\x0a\x0a    QWidgetName ------\x0a\x0aThis makes more easy to find and change some css field. The basic\x0aconfiguration is described bellow.\x0a\x0a    SELECTION ------------\x0a\x0a        sel_light  #179AE0 #148CD2 (selection/hover/active)\x0a        sel_normal #3375A3 #1464A0 (selected)\x0a        sel_dark   #18465D #14506E (selected disabled)\x0a\x0a    FOREGROUND -----------\x0a\x0a        for_light  #EFF0F1 #F0F0F0 (texts/labels)\x0a        for_dark   #505F69 #787878 (disabled texts)\x0a\x0a    BACKGROUND -----------\x0a\x0a        bac_light  #4D545B #505F69 (unpressed)\x0a        bac_normal #31363B #32414B (border, disabled, pressed, checked, toolbars, menus)\x0a        bac_dark   #232629 #19232D (background)\x0a\x0aIf a stranger configuration is required because of a bugfix or anything\x0aelse, keep the comment on that line to nobodys changed it, including the\x0aissue number.\x0a--------------------------------------------------------------------------- */\x0a\x0a\x0a\x0a/* QWidget ---------------------------------------------------------------- */\x0a\x0aQWidget {\x0a    background-color: #19232D;\x0a    border: 0px solid #32414B;\x0a    padding: 0px;\x0a    color: #F0F0F0;\x0a    selection-background-color: #1464A0;\x0a    selection-color: #F0F0F0;\x0a}\x0a\x0aQWidget:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a    selection-background-color: #14506E;\x0a    selection-color: #787878;\x0a}\x0a\x0aQWidget:item:selected {\x0a    background-color: #1464A0;\x0a}\x0a\x0aQWidget:item:hover {\x0a    background-color: #148CD2;\x0a    color: #32414B;\x0a}\x0a\x0a/* QMainWindow ------------------------------------------------------------ */\x0a/* This adjusts the splitter in the dock widget, not qsplitter              */\x0a\x0a\x0aQMainWindow::separator {\x0a    background-color: #32414B;\x0a    border: 0 solid #19232D;\x0a    spacing: 0;\x0a    padding: 2px;\x0a}\x0a\x0aQMainWindow::separator:hover {\x0a    background-color: #505F69;\x0a    border: 0px solid #148CD2;\x0a}\x0a\x0aQMainWindow::separator:horizontal {\x0a    width: 5px;\x0a    margin-top: 2px;\x0a    margin-bottom: 2px;\x0a    image: url(:/qss_icons/rc/Vsepartoolbar.png);\x0a}\x0a\x0aQMainWindow::separator:vertical {\x0a    height: 5px;\x0a    margin-left: 2px;\x0a    margin-right: 2px;\x0a    image: url(:/qss_icons/rc/Hsepartoolbar.png);\x0a}\x0a\x0a/* QToolTip --------------------------------------------------------------- */\x0a\x0aQToolTip {\x0a    background-color: #148CD2;\x0a    border: 1px solid #19232D;\x0a    color: #19232D;\x0a    padding: 0;   /*remove padding, for fix combo box tooltip*/\x0a    opacity: 230; /*reducing transparency to read better*/\x0a}\x0a\x0a/* QStatusBar ------------------------------------------------------------- */\x0a\x0aQStatusBar {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQStatusBar QToolTip {\x0a    background-color: #148CD2;\x0a    border: 1px solid #19232D;\x0a    color: #19232D;\x0a    padding: 0;   /*remove padding, for fix combo box tooltip*/\x0a    opacity: 230; /*reducing transparency to read better*/\x0a}\x0a\x0a/* QCheckBox -------------------------------------------------------------- */\x0a\x0aQCheckBox {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a    spacing: 4px;\x0a    outline: none;\x0a    padding-top: 4px;\x0a    padding-bottom: 4px;\x0a}\x0a\x0aQCheckBox:focus {\x0a    border: none;\x0a}\x0a\x0aQCheckBox QWidget:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0aQCheckBox::indicator {\x0a    margin-left: 4px;\x0a    width: 16px;\x0a    height: 16px;\x0a}\x0a\x0aQCheckBox::indicator:unchecked {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked.png);\x0a}\x0a\x0aQCheckBox::indicator:unchecked:hover,\x0aQCheckBox::indicator:unchecked:focus,\x0aQCheckBox::indicator:unchecked:pressed {\x0a    border: none;\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_focus.png);\x0a}\x0a\x0aQCheckBox::indicator:unchecked:disabled {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_disabled.png);\x0a}\x0a\x0aQCheckBox::indicator:checked {\x0a    image: url(:/qss_icons/rc/checkbox_checked.png);\x0a}\x0a\x0aQCheckBox::indicator:checked:hover,\x0aQCheckBox::indicator:checked:focus,\x0aQCheckBox::indicator:checked:pressed {\x0a    border: none;\x0a    image: url(:/qss_icons/rc/checkbox_checked_focus.png);\x0a}\x0a\x0aQCheckBox::indicator:checked:disabled{\x0a    image: url(:/qss_icons/rc/checkbox_checked_disabled.png);\x0a}\x0a\x0aQCheckBox::indicator:indeterminate {\x0a    image: url(:/qss_icons/rc/checkbox_indeterminate.png);\x0a}\x0a\x0aQCheckBox::indicator:indeterminate:disabled {\x0a    image: url(:/qss_icons/rc/checkbox_indeterminate_disabled.png);\x0a}\x0a\x0aQCheckBox::indicator:indeterminate:focus,\x0aQCheckBox::indicator:indeterminate:hover,\x0aQCheckBox::indicator:indeterminate:pressed {\x0a    image: url(:/qss_icons/rc/checkbox_indeterminate_focus.png);\x0a}\x0a\x0a/* QGroupBox -------------------------------------------------------------- */\x0a\x0aQGroupBox {\x0a    font-weight: bold;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    padding: 4px;\x0a    margin-top: 16px;\x0a}\x0a\x0a\x0a\x0aQGroupBox::title {\x0a    subcontrol-origin: margin;\x0a    subcontrol-position: top left;\x0a    left: 3px;\x0a    padding-left: 3px;\x0a    padding-right: 5px;\x0a    padding-top: 8px;\x0a    padding-bottom: 16px;\x0a}\x0a\x0aQGroupBox::indicator {\x0a    margin-left: 4px;\x0a    width: 16px;\x0a    height: 16px;\x0a}\x0a\x0aQGroupBox::indicator {\x0a    margin-left: 2px;\x0a}\x0a\x0aQGroupBox::indicator:unchecked:hover,\x0aQGroupBox::indicator:unchecked:focus,\x0aQGroupBox::indicator:unchecked:pressed {\x0a    border: none;\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_focus.png);\x0a}\x0a\x0aQGroupBox::indicator:checked:hover,\x0aQGroupBox::indicator:checked:focus,\x0aQGroupBox::indicator:checked:pressed {\x0a    border: none;\x0a    image: url(:/qss_icons/rc/checkbox_checked_focus.png);\x0a}\x0a\x0aQGroupBox::indicator:checked:disabled {\x0a    image: url(:/qss_icons/rc/checkbox_checked_disabled.png);\x0a}\x0a\x0aQGroupBox::indicator:unchecked:disabled {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_disabled.png);\x0a}\x0a\x0a/* QRadioButton ----------------------------------------------------------- */\x0a\x0aQRadioButton {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a    spacing: 0;\x0a    padding: 0;\x0a    border: none;\x0a    outline: none;\x0a}\x0a\x0aQRadioButton:focus {\x0a    border: none;\x0a}\x0a\x0aQRadioButton:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a    border: none;\x0a    outline: none;\x0a}\x0a\x0aQRadioButton QWidget {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a    spacing: 0px;\x0a    padding: 0px;\x0a    outline: none;\x0a    border: none;\x0a}\x0a\x0aQRadioButton::indicator {\x0a    border: none;\x0a    outline: none;\x0a    margin-bottom: 2px;\x0a    width: 25px;\x0a    height: 25px;\x0a}\x0a\x0aQRadioButton::indicator:unchecked {\x0a    image: url(:/qss_icons/rc/radio_unchecked.png);\x0a}\x0a\x0aQRadioButton::indicator:unchecked:hover,\x0aQRadioButton::indicator:unchecked:focus,\x0aQRadioButton::indicator:unchecked:pressed {\x0a    border: none;\x0a    outline: none;\x0a    image: url(:/qss_icons/rc/radio_unchecked_focus.png);\x0a}\x0a\x0aQRadioButton::indicator:checked {\x0a    border: none;\x0a    outline: none;\x0a    image: url(:/qss_icons/rc/radio_checked.png);\x0a}\x0a\x0aQRadioButton::indicator:checked:hover,\x0aQRadioButton::indicator:checked:focus,\x0aQRadioButton::indicator:checked:pressed {\x0a    border: none;\x0a    outline: none;\x0a    image: url(:/qss_icons/rc/radio_checked_focus.png);\x0a}\x0a\x0aQRadioButton::indicator:checked:disabled {\x0a    outline: none;\x0a    image: url(:/qss_icons/rc/radio_checked_disabled.png);\x0a}\x0a\x0aQRadioButton::indicator:unchecked:disabled {\x0a    image: url(:/qss_icons/rc/radio_unchecked_disabled.png);\x0a}\x0a\x0a/* QMenuBar --------------------------------------------------------------- */\x0a\x0aQMenuBar {\x0a    background-color: #32414B;\x0a    padding: 2px;\x0a    border: 1px solid #19232D;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQMenuBar:focus {\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0aQMenuBar::item {\x0a    background: transparent;\x0a    padding: 4px;\x0a}\x0a\x0aQMenuBar::item:selected {\x0a    padding: 4px;\x0a    background: transparent;\x0a    border: 0px solid #32414B;\x0a}\x0a\x0aQMenuBar::item:pressed {\x0a    padding: 4px;\x0a    border: 0px solid #32414B;\x0a    background-color: #148CD2;\x0a    color: #F0F0F0;\x0a    margin-bottom: 0px;\x0a    padding-bottom: 0px;\x0a}\x0a\x0a/* QMenu ------------------------------------------------------------------ */\x0a\x0aQMenu {\x0a    border: 0px solid #32414B;\x0a    color: #F0F0F0;\x0a    margin: 0px;\x0a}\x0a\x0aQMenu::separator {\x0a    height: 2px;\x0a    background-color: #505F69;\x0a    color: #F0F0F0;\x0a    padding-left: 4px;\x0a    margin-left: 2px;\x0a    margin-right: 2px;\x0a}\x0a\x0aQMenu::icon {\x0a    margin: 0px;\x0a    padding-left:4px;\x0a}\x0a\x0aQMenu::item {\x0a    padding: 4px 24px 4px 24px;\x0a    border: 1px transparent #32414B;  /* reserve space for selection border */\x0a}\x0a\x0aQMenu::item:selected {\x0a    color: #F0F0F0;\x0a}\x0a\x0a\x0a\x0aQMenu::indicator {\x0a    width: 12px;\x0a    height: 12px;\x0a    padding-left:6px;\x0a}\x0a\x0a/* non-exclusive indicator = check box style indicator (see QActionGroup::setExclusive) */\x0a\x0aQMenu::indicator:non-exclusive:unchecked {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked.png);\x0a}\x0a\x0aQMenu::indicator:non-exclusive:unchecked:selected {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_disabled.png);\x0a}\x0a\x0aQMenu::indicator:non-exclusive:checked {\x0a    image: url(:/qss_icons/rc/checkbox_checked.png);\x0a}\x0a\x0aQMenu::indicator:non-exclusive:checked:selected {\x0a    image: url(:/qss_icons/rc/checkbox_checked_disabled.png);\x0a}\x0a\x0a/* exclusive indicator = radio button style indicator (see QActionGroup::setExclusive) */\x0a\x0aQMenu::indicator:exclusive:unchecked {\x0a    image: url(:/qss_icons/rc/radio_unchecked.png);\x0a}\x0a\x0aQMenu::indicator:exclusive:unchecked:selected {\x0a    image: url(:/qss_icons/rc/radio_unchecked_disabled.png);\x0a}\x0a\x0aQMenu::indicator:exclusive:checked {\x0a    image: url(:/qss_icons/rc/radio_checked.png);\x0a}\x0a\x0aQMenu::indicator:exclusive:checked:selected {\x0a    image: url(:/qss_icons/rc/radio_checked_disabled.png);\x0a}\x0a\x0aQMenu::right-arrow {\x0a    margin: 5px;\x0a    image: url(:/qss_icons/rc/right_arrow.png)\x0a}\x0a\x0a/* QAbstractItemView ------------------------------------------------------ */\x0a\x0aQAbstractItemView {\x0a    alternate-background-color: #19232D;\x0a    color: #F0F0F0;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a}\x0a\x0aQAbstractItemView QLineEdit {\x0a    padding: 2px;\x0a}\x0a\x0a/* QAbstractScrollArea ---------------------------------------------------- */\x0a\x0aQAbstractScrollArea {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    padding: 4px;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQAbstractScrollArea:disabled {\x0a    color: #787878;\x0a}\x0a\x0a/* QScrollArea ------------------------------------------------------------ */\x0a\x0aQScrollArea QWidget QWidget:disabled {\x0a    background-color: #19232D;\x0a}\x0a\x0a/* QScrollBar ------------------------------------------------------------- */\x0a\x0aQScrollBar:horizontal {\x0a    height: 16px;\x0a    margin: 2px 16px 2px 16px;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    background-color: #19232D;\x0a}\x0a\x0aQScrollBar::handle:horizontal {\x0a    background-color: #787878;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    min-width: 8px;\x0a\x0a}\x0a\x0aQScrollBar::handle:horizontal:hover {\x0a    background-color: #148CD2;\x0a    border: 1px solid #148CD2;\x0a    border-radius: 4px;\x0a    min-width: 8px;\x0a}\x0a\x0aQScrollBar::add-line:horizontal {\x0a    margin: 0px 0px 0px 0px;\x0a    border-image: url(:/qss_icons/rc/right_arrow_disabled.png);\x0a    width: 10px;\x0a    height: 10px;\x0a    subcontrol-position: right;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::sub-line:horizontal {\x0a    margin: 0px 3px 0px 3px;\x0a    border-image: url(:/qss_icons/rc/left_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: left;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::add-line:horizontal:hover,\x0aQScrollBar::add-line:horizontal:on {\x0a    border-image: url(:/qss_icons/rc/right_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: right;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::sub-line:horizontal:hover,\x0aQScrollBar::sub-line:horizontal:on {\x0a    border-image: url(:/qss_icons/rc/left_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: left;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::up-arrow:horizontal,\x0aQScrollBar::down-arrow:horizontal {\x0a    background: none;\x0a}\x0a\x0aQScrollBar::add-page:horizontal,\x0aQScrollBar::sub-page:horizontal {\x0a    background: none;\x0a}\x0a\x0aQScrollBar:vertical {\x0a    background-color: #19232D;\x0a    width: 16px;\x0a    margin: 16px 2px 16px 2px;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a}\x0a\x0aQScrollBar::handle:vertical {\x0a    background-color: #787878;\x0a    border: 1px solid #32414B;\x0a    min-height: 8px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQScrollBar::handle:vertical:hover {\x0a    background-color: #148CD2;\x0a    border: 1px solid #148CD2;\x0a    border-radius: 4px;\x0a    min-height: 8px;\x0a\x0a}\x0a\x0aQScrollBar::sub-line:vertical {\x0a    margin: 3px 0px 3px 0px;\x0a    border-image: url(:/qss_icons/rc/up_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: top;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::add-line:vertical {\x0a    margin: 3px 0px 3px 0px;\x0a    border-image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: bottom;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::sub-line:vertical:hover,\x0aQScrollBar::sub-line:vertical:on {\x0a    border-image: url(:/qss_icons/rc/up_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: top;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::add-line:vertical:hover,\x0aQScrollBar::add-line:vertical:on {\x0a    border-image: url(:/qss_icons/rc/down_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: bottom;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::up-arrow:vertical,\x0aQScrollBar::down-arrow:vertical {\x0a    background: none;\x0a}\x0a\x0aQScrollBar::add-page:vertical,\x0aQScrollBar::sub-page:vertical {\x0a    background: none;\x0a}\x0a\x0a/* QTextEdit--------------------------------------------------------------- */\x0a\x0aQTextEdit {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQTextEdit:hover {\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQTextEdit:selected {\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a/* QPlainTextEdit --------------------------------------------------------- */\x0a\x0aQPlainTextEdit {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQPlainTextEdit:hover {\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQPlainTextEdit:selected {\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a/* QSizeGrip --------------------------------------------------------------- */\x0a\x0aQSizeGrip {\x0a    image: url(:/qss_icons/rc/sizegrip.png);\x0a    width: 12px;\x0a    height: 12px;\x0a}\x0a\x0a/* QStackedWidget --------------------------------------------------------- */\x0a\x0aQStackedWidget {\x0a    padding: 4px;\x0a    border: 1px solid #32414B;\x0a    border: 1px solid #19232D;\x0a}\x0a\x0a/* QToolBar --------------------------------------------------------------- */\x0a\x0aQToolBar {\x0a    background-color: #32414B;\x0a    border-bottom: 1px solid #19232D;\x0a    padding: 2px;\x0a    font-weight: bold;\x0a}\x0a\x0aQToolBar QToolButton{\x0a    background-color: #32414B;\x0a}\x0a\x0aQToolBar::handle:horizontal {\x0a    width: 6px;\x0a    image: url(:/qss_icons/rc/Hmovetoolbar.png);\x0a}\x0a\x0aQToolBar::handle:vertical {\x0a    height: 6px;\x0a    image: url(:/qss_icons/rc/Vmovetoolbar.png);\x0a}\x0a\x0aQToolBar::separator:horizontal {\x0a    width: 3px;\x0a    image: url(:/qss_icons/rc/Hsepartoolbar.png);\x0a}\x0a\x0aQToolBar::separator:vertical {\x0a    height: 3px;\x0a    image: url(:/qss_icons/rc/Vsepartoolbar.png);\x0a}\x0a\x0aQToolButton#qt_toolbar_ext_button {\x0a    background: #32414B;\x0a    border: 0px;\x0a    color: #F0F0F0;\x0a    image: url(:/qss_icons/rc/right_arrow.png);\x0a}\x0a\x0a/* QAbstractSpinBox ------------------------------------------------------- */\x0a\x0aQAbstractSpinBox {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    padding-top: 2px;     /* This fix  103, 111*/\x0a    padding-bottom: 2px;  /* This fix  103, 111*/\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    border-radius: 4px;\x0a    /* min-width: 5px; removed to fix 109 */\x0a}\x0a\x0aQAbstractSpinBox:up-button {\x0a    background-color: transparent #19232D;\x0a    subcontrol-origin: border;\x0a    subcontrol-position: top right;\x0a    border-left: 1px solid #32414B;\x0a    margin: 1px;\x0a}\x0a\x0aQAbstractSpinBox::up-arrow,\x0aQAbstractSpinBox::up-arrow:disabled,\x0aQAbstractSpinBox::up-arrow:off {\x0a    image: url(:/qss_icons/rc/up_arrow_disabled.png);\x0a    width: 9px;\x0a    height: 9px;\x0a}\x0a\x0aQAbstractSpinBox::up-arrow:hover {\x0a    image: url(:/qss_icons/rc/up_arrow.png);\x0a}\x0a\x0aQAbstractSpinBox:down-button {\x0a    background-color: transparent #19232D;\x0a    subcontrol-origin: border;\x0a    subcontrol-position: bottom right;\x0a    border-left: 1px solid #32414B;\x0a    margin: 1px;\x0a}\x0a\x0aQAbstractSpinBox::down-arrow,\x0aQAbstractSpinBox::down-arrow:disabled,\x0aQAbstractSpinBox::down-arrow:off {\x0a    image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a    width: 9px;\x0a    height: 9px;\x0a}\x0a\x0aQAbstractSpinBox::down-arrow:hover {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQAbstractSpinBox:hover{\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQAbstractSpinBox:selected {\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a/* ------------------------------------------------------------------------ */\x0a/* DISPLAYS --------------------------------------------------------------- */\x0a/* ------------------------------------------------------------------------ */\x0a\x0a/* QLabel ----------------------------------------------------------------- */\x0a\x0aQLabel {\x0a    background-color: #19232D;\x0a    border: 0px solid #32414B;\x0a    padding: 2px;\x0a    margin: 0px;\x0a    color: #F0F0F0\x0a}\x0a\x0aQLabel::disabled {\x0a    background-color: #19232D;\x0a    border: 0px solid #32414B;\x0a    color: #787878;\x0a}\x0a\x0a/* QTextBrowser ----------------------------------------------------------- */\x0a\x0aQTextBrowser {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a}\x0a\x0aQTextBrowser:disabled {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a}\x0a\x0aQTextBrowser:hover,\x0aQTextBrowser:!hover,\x0aQTextBrowser::selected,\x0aQTextBrowser::pressed {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0a/* QGraphicsView --------------------------------------------------------- */\x0a\x0aQGraphicsView {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a}\x0a\x0aQGraphicsView:disabled {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a}\x0a\x0aQGraphicsView:hover,\x0aQGraphicsView:!hover,\x0aQGraphicsView::selected,\x0aQGraphicsView::pressed {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0a/* QCalendarWidget -------------------------------------------------------- */\x0a\x0aQCalendarWidget {\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a}\x0a\x0aQCalendarWidget:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0a/* QLCDNumber ------------------------------------------------------------- */\x0a\x0aQLCDNumber {\x0a    background-color: #19232D;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQLCDNumber:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0a/* QProgressBar ----------------------------------------------------------- */\x0a\x0aQProgressBar {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a    text-align: center;\x0a}\x0a\x0aQProgressBar:disabled {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a    text-align: center;\x0a}\x0a\x0aQProgressBar::chunk {\x0a    background-color: #1464A0;\x0a    color: #19232D;\x0a    border-radius: 4px;\x0a}\x0a\x0aQProgressBar::chunk:disabled {\x0a    background-color: #14506E;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a}\x0a\x0a\x0a/* ------------------------------------------------------------------------ */\x0a/* BUTTONS ---------------------------------------------------------------- */\x0a/* ------------------------------------------------------------------------ */\x0a\x0a/* QPushButton ------------------------------------------------------------ */\x0a\x0aQPushButton {\x0a    background-color: #505F69 ;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a    padding: 3px;\x0a    outline: none;\x0a}\x0a\x0aQPushButton:disabled {\x0a    background-color: #32414B;\x0a    border: 1px solid #32414B;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a    padding: 3px;\x0a}\x0a\x0a\x0aQPushButton:checked {\x0a    background-color: #32414B;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    padding: 3px;\x0a    outline: none;\x0a}\x0a\x0aQPushButton:checked:disabled {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #787878;\x0a    border-radius: 4px;\x0a    padding: 3px;\x0a    outline: none;\x0a}\x0a\x0aQPushButton::menu-indicator {\x0a    subcontrol-origin: padding;\x0a    subcontrol-position: bottom right;\x0a    bottom: 4px;\x0a}\x0a\x0aQPushButton:pressed {\x0a    background-color: #19232D;\x0a    border: 1px solid #19232D;\x0a}\x0a\x0aQPushButton:hover,\x0aQPushButton:checked:hover{\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQPushButton:selected,\x0aQPushButton:checked:selected{\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a/* QToolButton ------------------------------------------------------------ */\x0a\x0aQToolButton {\x0a    background-color: transparent;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    margin: 0px;\x0a    padding: 2px;\x0a}\x0a\x0aQToolButton:checked {\x0a    background-color: #19232D;\x0a    border: 1px solid #19232D;\x0a}\x0a\x0aQToolButton:disabled {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQToolButton:hover,\x0aQToolButton:checked:hover{\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0a/* the subcontrols below are used only in the MenuButtonPopup mode */\x0a\x0aQToolButton[popupMode=\x221\x22] {\x0a    padding: 2px;\x0a    padding-right: 12px;     /* only for MenuButtonPopup */\x0a    border: 1px solid #32414B;   /* make way for the popup button */\x0a    border-radius: 4px;\x0a}\x0a\x0a/* The subcontrol below is used only in the InstantPopup or DelayedPopup mode */\x0a\x0aQToolButton[popupMode=\x222\x22] {\x0a    padding: 2px;\x0a    padding-right: 12px;      /* only for InstantPopup */\x0a    border: 1px solid #32414B;    /* make way for the popup button */\x0a}\x0a\x0aQToolButton::menu-button {\x0a    padding: 2px;\x0a    border-radius: 4px;\x0a    border: 1px solid #32414B;\x0a    border-top-right-radius: 4px;\x0a    border-bottom-right-radius: 4px;\x0a    /* 16px width + 4px for border = 20px allocated above */\x0a    width: 16px;\x0a    outline: none;\x0a}\x0a\x0aQToolButton::menu-button:hover,\x0aQToolButton::menu-button:checked:hover {\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0aQToolButton::menu-indicator {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a    top: -8px;     /* shift it a bit */\x0a    left: -4px;    /* shift it a bit */\x0a}\x0a\x0aQToolButton::menu-arrow {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQToolButton::menu-arrow:open {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0a/* QCommandLinkButton ----------------------------------------------------- */\x0a\x0aQCommandLinkButton {\x0a    background-color: transparent;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-radius: 4px;\x0a    padding: 0px;\x0a    margin: 0px;\x0a}\x0a\x0aQCommandLinkButton:disabled {\x0a    background-color: transparent;\x0a    color: #787878;\x0a}\x0a\x0a/* ------------------------------------------------------------------------ */\x0a/* INPUTS - NO FIELDS ----------------------------------------------------- */\x0a/* ------------------------------------------------------------------------ */\x0a\x0a/* QCombobox -------------------------------------------------------------- */\x0a\x0aQComboBox {\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    selection-background-color: #1464A0;\x0a    padding-top: 2px;     /* This fix  #103, #111*/\x0a    padding-bottom: 2px;  /* This fix  #103, #111*/\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    /* min-width: 75px;  removed to fix 109 */\x0a}\x0a\x0aQComboBox:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0aQComboBox:hover{\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0aQComboBox:on {\x0a    selection-background-color: #19232D;\x0a}\x0a\x0aQComboBox QAbstractItemView {\x0a    background-color: #19232D;\x0a    border-radius: 4px;\x0a    border: 1px solid #32414B;\x0a    selection-color: #148CD2;\x0a    selection-background-color: #32414B;\x0a}\x0a\x0aQComboBox::drop-down {\x0a    subcontrol-origin: padding;\x0a    subcontrol-position: top right;\x0a    width: 20px;\x0a    border-left-width: 0px;\x0a    border-left-color: #32414B;\x0a    border-left-style: solid;\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQComboBox::down-arrow {\x0a    image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a}\x0a\x0aQComboBox::down-arrow:on,\x0aQComboBox::down-arrow:hover,\x0aQComboBox::down-arrow:focus {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0a/* QSlider ---------------------------------------------------------------- */\x0a\x0aQSlider:disabled {\x0a    background: #19232D;\x0a}\x0a\x0aQSlider:focus {\x0a    border: none;\x0a}\x0a\x0aQSlider::groove:horizontal {\x0a    background: #32414B;\x0a    border: 1px solid #32414B;\x0a    height: 4px;\x0a    margin: 0px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::sub-page:horizontal {\x0a    background: #1464A0;\x0a    border: 1px solid #32414B;\x0a    height: 4px;\x0a    margin: 0px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::sub-page:horizontal:disabled {\x0a    background: #14506E;\x0a}\x0a\x0aQSlider::handle:horizontal {\x0a    background: #787878;\x0a    border: 1px solid #32414B;\x0a    width: 8px;\x0a    height: 8px;\x0a    margin: -8px 0;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::handle:horizontal:hover {\x0a    background: #148CD2;\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0aQSlider::groove:vertical {\x0a    background: #32414B;\x0a    border: 1px solid #32414B;\x0a    width: 4px;\x0a    margin: 0px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::sub-page:vertical {\x0a    background: #1464A0;\x0a    border: 1px solid #32414B;\x0a    width: 4px;\x0a    margin: 0px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::sub-page:vertical:disabled {\x0a    background: #14506E;\x0a}\x0a\x0aQSlider::handle:vertical {\x0a    background: #787878;\x0a    border: 1px solid #32414B;\x0a    width: 8px;\x0a    height: 8px;\x0a    margin: 0 -8px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::handle:vertical:hover {\x0a    background: #148CD2;\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0a/* QLine ------------------------------------------------------------------ */\x0a\x0aQLineEdit {\x0a    background-color: #19232D;\x0a    padding-top: 2px;     /* This QLineEdit fix  103, 111 */\x0a    padding-bottom: 2px;  /* This QLineEdit fix  103, 111 */\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    border-style: solid;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQLineEdit:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0aQLineEdit:hover{\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQLineEdit:selected{\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a/* QTabWiget -------------------------------------------------------------- */\x0a\x0aQTabWidget {\x0a    padding: 2px;\x0a    selection-background-color: #32414B;\x0a}\x0a\x0aQTabWidget QFrame{\x0a    border: 0;\x0a}\x0a\x0aQTabWidget::pane {\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    padding: 2px;\x0a    margin: 0px;\x0a}\x0a\x0aQTabWidget::pane:selected {\x0a    background-color: #32414B;\x0a    border: 1px solid #1464A0;\x0a}\x0a\x0a/* QTabBar ---------------------------------------------------------------- */\x0a\x0aQTabBar {\x0a    qproperty-drawBase: 0;\x0a    border-radius: 4px;\x0a    margin: 0px;\x0a    padding: 2px;\x0a    border: 0;\x0a\x0a    /* left: 5px; move to the right by 5px - removed for fix */\x0a    }\x0a\x0aQTabBar::close-button {\x0a    border: 0;\x0a    margin: 2px;\x0a    padding: 0;\x0a    image: url(:/qss_icons/rc/close.png);\x0a}\x0a\x0aQTabBar::close-button:hover {\x0a    image: url(:/qss_icons/rc/close-hover.png);\x0a}\x0a\x0aQTabBar::close-button:pressed {\x0a    image: url(:/qss_icons/rc/close-pressed.png);\x0a}\x0a\x0a/* QTabBar::tab - selected ----------------------------------------------- */\x0a\x0aQTabBar::tab:top:selected:disabled {\x0a    border-bottom: 3px solid #14506E;\x0a    color: #787878;\x0a    background-color: #32414B;\x0a}\x0a\x0aQTabBar::tab:bottom:selected:disabled {\x0a    border-top: 3px solid #14506E;\x0a    color: #787878;\x0a    background-color: #32414B;\x0a}\x0a\x0aQTabBar::tab:left:selected:disabled {\x0a    border-left: 3px solid #14506E;\x0a    color: #787878;\x0a    background-color: #32414B;\x0a}\x0a\x0aQTabBar::tab:right:selected:disabled {\x0a    border-right: 3px solid #14506E;\x0a    color: #787878;\x0a    background-color: #32414B;\x0a}\x0a\x0a/* QTabBar::tab - !selected and disabled ---------------------------------- */\x0a\x0aQTabBar::tab:top:!selected:disabled {\x0a    border-bottom: 3px solid #19232D;\x0a    color: #787878;\x0a    background-color: #19232D;\x0a}\x0a\x0aQTabBar::tab:bottom:!selected:disabled {\x0a    border-top: 3px solid #19232D;\x0a    color: #787878;\x0a    background-color: #19232D;\x0a}\x0a\x0aQTabBar::tab:left:!selected:disabled {\x0a    border-right: 3px solid #19232D;\x0a    color: #787878;\x0a    background-color: #19232D;\x0a}\x0a\x0aQTabBar::tab:right:!selected:disabled {\x0a    border-left: 3px solid #19232D;\x0a    color: #787878;\x0a    background-color: #19232D;\x0a}\x0a\x0a/* QTabBar::tab - selected ----------------------------------------------- */\x0a\x0aQTabBar::tab:top:!selected {\x0a    border-bottom: 2px solid #19232D;\x0a    margin-top: 2px;\x0a}\x0a\x0aQTabBar::tab:bottom:!selected {\x0a    border-top: 2px solid #19232D;\x0a    margin-bottom: 3px;\x0a}\x0a\x0aQTabBar::tab:left:!selected {\x0a    border-left: 2px solid #19232D;\x0a    margin-right: 2px;\x0a}\x0a\x0aQTabBar::tab:right:!selected {\x0a    border-right: 2px solid #19232D;\x0a    margin-left: 2px;\x0a}\x0a\x0a\x0aQTabBar::tab:top {\x0a    background-color: #32414B;\x0a    color: #F0F0F0;\x0a    margin-left: 2px;\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    padding-top: 2px;\x0a    padding-bottom: 2px;\x0a    min-width: 5px;\x0a    border-bottom: 3px solid #32414B;\x0a    border-top-left-radius: 3px;\x0a    border-top-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:top:selected {\x0a    background-color: #505F69;\x0a    color: #F0F0F0;\x0a    border-bottom: 3px solid #1464A0;\x0a    border-top-left-radius: 3px;\x0a    border-top-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:top:!selected:hover {\x0a    border: 1px solid #148CD2;\x0a    border-bottom: 3px solid #148CD2;\x0a}\x0a\x0aQTabBar::tab:bottom {\x0a    color: #F0F0F0;\x0a    border-top: 3px solid #32414B;\x0a    background-color: #32414B;\x0a    margin-left: 2px;\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    padding-top: 2px;\x0a    padding-bottom: 2px;\x0a    border-bottom-left-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a    min-width: 5px;\x0a}\x0a\x0aQTabBar::tab:bottom:selected {\x0a    color: #F0F0F0;\x0a    background-color: #505F69;\x0a    border-top: 3px solid #1464A0;\x0a    border-bottom-left-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:bottom:!selected:hover {\x0a    border: 1px solid #148CD2;\x0a    border-top: 3px solid #148CD2;\x0a}\x0a\x0aQTabBar::tab:left {\x0a    color: #F0F0F0;\x0a    background-color: #32414B;\x0a    margin-top: 2px;\x0a    padding-left: 2px;\x0a    padding-right: 2px;\x0a    padding-top: 4px;\x0a    padding-bottom: 4px;\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a    min-height: 5px;\x0a}\x0a\x0aQTabBar::tab:left:selected {\x0a    color: #F0F0F0;\x0a    background-color: #505F69;\x0a    border-left: 3px solid #1464A0;\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:left:!selected:hover {\x0a    border: 1px solid #148CD2;\x0a    border-left: 3px solid #148CD2;\x0a}\x0a\x0aQTabBar::tab:right {\x0a    color: #F0F0F0;\x0a    background-color: #32414B;\x0a    margin-top: 2px;\x0a    padding-left: 2px;\x0a    padding-right: 2px;\x0a    padding-top: 4px;\x0a    padding-bottom: 4px;\x0a    border-top-left-radius: 3px;\x0a    border-bottom-left-radius: 3px;\x0a    min-height: 5px;\x0a}\x0a\x0aQTabBar::tab:right:selected {\x0a    color: #F0F0F0;\x0a    background-color: #505F69;\x0a    border-right: 3px solid #1464A0;\x0a    border-top-left-radius: 3px;\x0a    border-bottom-left-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:right:!selected:hover {\x0a    border: 1px solid #148CD2;\x0a    border-right: 3px solid #148CD2;\x0a}\x0a\x0aQTabBar QToolButton::right-arrow:enabled {\x0a    image: url(:/qss_icons/rc/right_arrow.png);\x0a}\x0a\x0aQTabBar QToolButton::left-arrow:enabled {\x0a    image: url(:/qss_icons/rc/left_arrow.png);\x0a}\x0a\x0aQTabBar QToolButton::right-arrow:disabled {\x0a    image: url(:/qss_icons/rc/right_arrow_disabled.png);\x0a}\x0a\x0aQTabBar QToolButton::left-arrow:disabled {\x0a    image: url(:/qss_icons/rc/left_arrow_disabled.png);\x0a}\x0a\x0a\x0a/*  Some examples from internet to check\x0a\x0aQTabBar::tabButton() and QTabBar::tabIcon()\x0aQTabBar::tear {width: 0px; border: none;}\x0aQTabBar::tear {image: url(tear_indicator.png);}\x0aQTabBar::scroller{width:85pix;}\x0aQTabBar QToolbutton{background-color:\x22light blue\x22;}\x0a\x0aBut that left the buttons transparant.\x0aLooked confusing as the tab buttons migrated behind the scroller buttons.\x0aSo we had to color the back ground of the scroller buttons\x0a*/\x0a\x0a/* QDockWiget ------------------------------------------------------------- */\x0a\x0aQDockWidget {\x0a    outline: 1px solid #32414B;\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    titlebar-close-icon: url(:/qss_icons/rc/close.png);\x0a    titlebar-normal-icon: url(:/qss_icons/rc/undock.png);\x0a}\x0a\x0aQDockWidget::title {\x0a    padding: 6px;   /* better size for title bar */\x0a    border: none;\x0a    background-color: #32414B;\x0a}\x0a\x0aQDockWidget::close-button {\x0a    background-color: #32414B;\x0a    border-radius: 4px;\x0a    border: none;\x0a}\x0a\x0aQDockWidget::close-button:hover {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQDockWidget::close-button:pressed {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQDockWidget::float-button {\x0a    background-color: #32414B;\x0a    border-radius: 4px;\x0a    border: none;\x0a}\x0a\x0aQDockWidget::float-button:hover {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQDockWidget::float-button:pressed {\x0a    border: 1px solid #32414B;\x0a}\x0a\x0a\x0a/* QTreeView QTableView QListView ----------------------------------------- */\x0a\x0aQTreeView:branch:selected,\x0aQTreeView:branch:hover {\x0a    background: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-siblings:!adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-siblings:adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:!has-children:!has-siblings:adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-children:!has-siblings:closed,\x0aQTreeView::branch:closed:has-children:has-siblings {\x0a    image: url(:/qss_icons/rc/branch_closed.png);\x0a}\x0a\x0aQTreeView::branch:open:has-children:!has-siblings,\x0aQTreeView::branch:open:has-children:has-siblings {\x0a    image: url(:/qss_icons/rc/branch_open.png);\x0a}\x0a\x0aQTreeView::branch:has-children:!has-siblings:closed:hover,\x0aQTreeView::branch:closed:has-children:has-siblings:hover {\x0a    image: url(:/qss_icons/rc/branch_closed-on.png);\x0a}\x0a\x0aQTreeView::branch:open:has-children:!has-siblings:hover,\x0aQTreeView::branch:open:has-children:has-siblings:hover {\x0a    image: url(:/qss_icons/rc/branch_open-on.png);\x0a}\x0a\x0aQListView::item:!selected:hover,\x0aQTreeView::item:!selected:hover,\x0aQTableView::item:!selected:hover,\x0aQColumnView::item:!selected:hover {\x0a    outline: 0;\x0a    color: #148CD2;\x0a    background-color: #32414B;\x0a}\x0a\x0aQListView::item:selected:hover,\x0aQTreeView::item:selected:hover,\x0aQTableView::item:selected:hover,\x0aQColumnView::item:selected:hover {\x0a    background: #1464A0;\x0a    color:  #19232D;\x0a}\x0a\x0aQTreeView::indicator:checked,\x0aQListView::indicator:checked {\x0a    image: url(:/qss_icons/rc/checkbox_checked.png);\x0a}\x0a\x0aQTreeView::indicator:unchecked,\x0aQListView::indicator:unchecked {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked.png);\x0a}\x0a\x0aQTreeView::indicator:checked:hover,\x0aQTreeView::indicator:checked:focus,\x0aQTreeView::indicator:checked:pressed,\x0aQListView::indicator:checked:hover,\x0aQListView::indicator:checked:focus,\x0aQListView::indicator:checked:pressed {\x0a    image: url(:/qss_icons/rc/checkbox_checked_focus.png);\x0a}\x0a\x0aQTreeView::indicator:unchecked:hover,\x0aQTreeView::indicator:unchecked:focus,\x0aQTreeView::indicator:unchecked:pressed,\x0aQListView::indicator:unchecked:hover,\x0aQListView::indicator:unchecked:focus,\x0aQListView::indicator:unchecked:pressed {\x0a    image: url(:/qss_icons/rc/checkbox_unchecked_focus.png);\x0a}\x0a\x0aQTreeView::indicator:indeterminate:hover,\x0aQTreeView::indicator:indeterminate:focus,\x0aQTreeView::indicator:indeterminate:pressed,\x0aQListView::indicator:indeterminate:hover,\x0aQListView::indicator:indeterminate:focus,\x0aQListView::indicator:indeterminate:pressed {\x0a    image: url(:/qss_icons/rc/checkbox_indeterminate_focus.png);\x0a}\x0a\x0aQTreeView::indicator:indeterminate,\x0aQListView::indicator:indeterminate {\x0a    image: url(:/qss_icons/rc/checkbox_indeterminate.png);\x0a}\x0a\x0aQListView,\x0aQTreeView,\x0aQTableView,\x0aQColumnView {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    gridline-color: #32414B;\x0a    border-radius: 4px;\x0a}\x0a\x0aQListView:disabled,\x0aQTreeView:disabled,\x0aQTableView:disabled,\x0aQColumnView:disabled {\x0a    background-color: #19232D;\x0a    color: #787878;\x0a}\x0a\x0aQListView:selected,\x0aQTreeView:selected,\x0aQTableView:selected,\x0aQColumnView:selected {\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0aQListView:hover,\x0aQTreeView::hover,\x0aQTableView::hover,\x0aQColumnView::hover {\x0a    background-color: #19232D;\x0a    border: 1px solid #148CD2;\x0a}\x0a\x0aQListView::item:pressed,\x0aQTreeView::item:pressed,\x0aQTableView::item:pressed,\x0aQColumnView::item:pressed {\x0a    background-color: #1464A0;\x0a}\x0a\x0aQListView::item:selected:active,\x0aQTreeView::item:selected:active,\x0aQTableView::item:selected:active,\x0aQColumnView::item:selected:active {\x0a    background-color: #1464A0;\x0a}\x0a\x0aQTableCornerButton::section {\x0a    background-color: #19232D;\x0a    border: 1px transparent #32414B;\x0a    border-radius: 0px;\x0a}\x0a\x0a/* QHeaderView ------------------------------------------------------------ */\x0a\x0aQHeaderView {\x0a    background-color: #32414B;\x0a    border: 0px transparent #32414B;\x0a    padding: 0px;\x0a    margin: 0px;\x0a    border-radius: 0px;\x0a}\x0a\x0aQHeaderView:disabled {\x0a    background-color: #32414B;\x0a    border: 1px transparent #32414B;\x0a    padding: 2px;\x0a}\x0a\x0aQHeaderView::section {\x0a    background-color: #32414B;\x0a    color: #F0F0F0;\x0a    padding: 2px;\x0a    border-radius: 0px;\x0a    text-align: left;\x0a}\x0a\x0aQHeaderView::section:checked {\x0a    color: #F0F0F0;\x0a    background-color: #1464A0;\x0a}\x0a\x0aQHeaderView::section:checked:disabled {\x0a    color: #787878;\x0a    background-color: #14506E;\x0a}\x0a\x0aQHeaderView::section::horizontal:disabled,\x0aQHeaderView::section::vertical:disabled {\x0a    color: #787878;\x0a}\x0a\x0aQHeaderView::section::vertical::first,\x0aQHeaderView::section::vertical::only-one {\x0a    border-top: 1px solid #32414B;\x0a}\x0a\x0aQHeaderView::section::vertical {\x0a    border-top: 1px solid #19232D;\x0a}\x0a\x0aQHeaderView::section::horizontal::first,\x0aQHeaderView::section::horizontal::only-one {\x0a    border-left: 1px solid #32414B;\x0a}\x0a\x0aQHeaderView::section::horizontal {\x0a    border-left: 1px solid #19232D;\x0a}\x0a\x0a/* Those settings (border/width/height/background-color) solve bug */\x0a/* transparent arrow background and size */\x0a\x0aQHeaderView::down-arrow {\x0a    background-color: #32414B;\x0a    width: 16px;\x0a    height: 16px;\x0a    border-right: 1px solid #19232D;\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQHeaderView::up-arrow {\x0a    background-color: #32414B;\x0a    width: 16px;\x0a    height: 16px;\x0a    border-right: 1px solid #19232D;\x0a    image: url(:/qss_icons/rc/up_arrow.png);\x0a}\x0a\x0a/* QToolBox -------------------------------------------------------------- */\x0a\x0aQToolBox {\x0a    padding: 0px;\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQToolBox::selected {\x0a    padding: 0px;\x0a    border: 2px solid #1464A0;\x0a}\x0a\x0aQToolBox::tab {\x0a    background-color: #19232D;\x0a    border: 1px solid #32414B;\x0a    color: #F0F0F0;\x0a    border-top-left-radius: 4px;\x0a    border-top-right-radius: 4px;\x0a}\x0a\x0aQToolBox::tab:disabled {\x0a    color: #787878;\x0a}\x0a\x0aQToolBox::tab:selected {\x0a    background-color: #505F69;\x0a    border-bottom: 2px solid #1464A0;\x0a}\x0a\x0aQToolBox::tab:!selected {\x0a    background-color: #32414B;\x0a    border-bottom: 2px solid #32414B;\x0a}\x0a\x0aQToolBox::tab:selected:disabled {\x0a    background-color: #32414B;\x0a    border-bottom: 2px solid #14506E;\x0a}\x0a\x0aQToolBox::tab:!selected:disabled {\x0a    background-color: #19232D;\x0a}\x0a\x0aQToolBox::tab:hover {\x0a    border-color: #148CD2;\x0a    border-bottom: 2px solid #148CD2;\x0a}\x0a\x0aQToolBox QScrollArea QWidget QWidget {\x0a    padding: 0px;\x0a    background-color: #19232D;\x0a}\x0a\x0a/* QFrame ----------------------------------------------------------------- */\x0a\x0aQFrame {\x0a    border-radius: 4px;\x0a    border: 1px solid #32414B;\x0a}\x0a\x0aQFrame[frameShape=\x220\x22] {\x0a    border-radius: 4px;\x0a    border: 1px transparent #32414B;\x0a}\x0a\x0aQFrame[height=\x223\x22],\x0aQFrame[width=\x223\x22] {\x0a    background-color: #19232D;\x0a}\x0a\x0a/* QSplitter -------------------------------------------------------------- */\x0a\x0aQSplitter {\x0a    background-color: #32414B;\x0a    spacing: 0;\x0a    padding: 0;\x0a    margin: 0;\x0a}\x0a\x0aQSplitter::separator {\x0a    background-color: #32414B;\x0a    border: 0 solid #19232D;\x0a    spacing: 0;\x0a    padding: 1px;\x0a    margin: 0;\x0a}\x0a\x0aQSplitter::separator:hover {\x0a    background-color: #787878;\x0a}\x0a\x0aQSplitter::separator:horizontal {\x0a    width: 5px;\x0a    image: url(:/qss_icons/rc/Vsepartoolbar.png);\x0a}\x0a\x0aQSplitter::separator:vertical {\x0a    height: 5px;\x0a    image: url(:/qss_icons/rc/Hsepartoolbar.png);\x0a}\x0a\x0a\x0a/* QDateEdit-------------------------------------------------------------- */\x0a\x0aQDateEdit {\x0a    selection-background-color: #1464A0;\x0a    border-style: solid;\x0a    border: 1px solid #32414B;\x0a    border-radius: 4px;\x0a    padding-top: 2px;     /* This fix  #103, #111*/\x0a    padding-bottom: 2px;  /* This fix  #103, #111*/\x0a    padding-left: 4px;\x0a    padding-right: 4px;\x0a    min-width: 10px;\x0a}\x0a\x0aQDateEdit:on {\x0a    selection-background-color: #1464A0;\x0a}\x0a\x0aQDateEdit::drop-down {\x0a    subcontrol-origin: padding;\x0a    subcontrol-position: top right;\x0a    width: 20px;\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQDateEdit::down-arrow {\x0a    image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a}\x0a\x0aQDateEdit::down-arrow:on,\x0aQDateEdit::down-arrow:hover,\x0aQDateEdit::down-arrow:focus {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQDateEdit QAbstractItemView {\x0a    background-color: #19232D;\x0a    border-radius: 4px;\x0a    border: 1px solid #32414B;\x0a    selection-background-color: #1464A0;\x0a}\x0a\x0aQAbstractView:hover{\x0a    border: 1px solid #148CD2;\x0a    color: #F0F0F0;\x0a}\x0a\x0aQAbstractView:selected {\x0a    background: #1464A0;\x0a    color: #32414B;\x0a}\x0a\x0a\x0a\x00\x00\x03\xac\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x03)IDATX\x85\xed\x95Oh\x5cU\x14\xc6\x7f\xe7e\x88d\xda\xc6\xbd\xa9\x94HW\xb6\x91:(\xae\xd3M\xc5\x0aM@fc\xda7/%\xcdF\x07\xd1$\x8e\xae\xb2P\xa8I\xddd\x99\xc2\xbc\x19\xd3n\x9e S\xc1\xe2\x9f\x85u\x1b\xfc\xd3\xa4\x15\x91RJpJ\xd7%3$\xcd\xe0\xfb\x5c\xbc7M\x90\xbc7\x1d\xe9\xce\xf9V\xf7\xcfw\xce\xfd\xee9\xe7\x9e\x0b=\xf4\xf0\x7f\x87uC\x0e\x82\xa0\x7f\xab\xd1\x18\x97\xd9\x98A\x0e\x18\x8a\xb7\xea\x98\xfd*\xa8e\xb3\xd9Z>\x9f\xdfy\xea\x02\xaa\xe5\xf2[\x98-\x00\xc3\x06\xb7\x047dV\x07p\xc2p\x08\xb3Q\xc1\x08p\xd7`\xee\x9c\xe7}\xf5T\x04\x04A\xd0\xb7\xd5l.\x00\xef\x1b|kaX:{\xfe\xfc\xda~\x5c\xdf\xf7O8p\x118\x05,\xde\xdb\xd8(\xcd\xcf\xcf\x87i\xfe3\x9d\x04\xc4\x87\xbf'i\xd6\x9d\x9c\xbc\x94\xc6\xf5<\xef&\xf0z\xd5\xf7g\x81\x8b\xc3G\x8e\x00\xcc\xa5\xd9\xa4F \x0e\xfb\x97f6s\xaeP\xf8\x1c`ii\xe9\x99\xc1\xc1\xc1i\x93\xde&\x0a9&\xad\xcb\xec\xea\xc3\xcd\xcd\xe5b\xb1\xf8\x08\xa0R\xa9\xcc\x99\xf4\x99\x03\xe3g=\xaf\xd6\xb5\x80 \x08\xfa\xb7\x9b\xcd?$\xfd\xe9NN\xbe\x01p\xe5\xf2\xe5\xc3a&s=\xceu\x0881=\x1a\x9b\xad\xf7\xb5Z\xa7'\xa6\xa6\xea\x00\x15\xdf\xff\xde\xcc\x86\x07\xb2\xd9cI\x85\xe9\xec\xb7\x08\xb0\xd5h\x8c\x0b^p\xa4\x8f\xda7\x0f3\x99\xeb2;\xbe\x8fm{<\xf2w&\xf3M\x10\x04\xfd\x00\xe68\x1f\x22\x1d\xddn6\xcf$\x9d\x93(@fc\xc0Z\xbb\xe0\x9e=t\xe8\x82`\x04)9m\xd1\xdeK[\x8d\xc6\x05\x00\xd7u\x7f\xc3\xec6\xd0\xbd\x00\x83\x9cI?\xedY\x9a \x0au:\xa4\xd0\x22n{\xfe\xa3\xe0\x95\xae\x05`\xf6\x5c\xfb\x9d\xc78\x96\xca\xdf\xb5s\x14q\xdb\xb8\x8f\xd9P\x12=\xd5\xa1\xcc\xba\xea\x94\xfb\xea\x01CJ\x8c\x5c\xb2\x00\xe9\x81I\x87\xf7\xac\xfc\xce\x13\xa6@p\xfb\xf14\xba\xfd\x83\xee\x05\x98\xfd\x8c\xd9\xe8\x9e\x95+\xa9\xfc];\xc7\xe0\xea\xae\x1e\x9d\x04V\xbb\x16 \xa8!\x1d\xf7}\xff\x04\xc0\xc3\xcd\xcde\xcc\xd61S\xca\xe1\x02n\x0e\x1c<\xb8\x0c\xb0R.\xe7\x0c^D\xfa\xbak\x01\xd9l\xb6\x06\xdc\x8d{;\xc5b\xf1Q_\xabu\x1a\xb8\x15Sv\xd3\xd1\xce\xb1\xb4\x86\xe3\xbc\x99\xcf\xe7w$Y\x18}^w\xb6[\xadk]\x0b\xc8\xe7\xf3;8\xce,p*\xee\xedLLM\xd5\x07\xb2\xd9W\x91\xde\x95\xb4\x0a4\x81\xa6`\xd5\xcc\xde\x198p\xe05\xd7u\xef\x03T}\xbf\x04\x9c\x94\xd9\xcc\xf4\xf4t+\xe9\x9c\x8eU^\xf5\xfd\x05\xe0\x03\xa0\xe4z\xdeb'\xbe$\xab\xfa~\xc9\xcc>\x01\x16]\xcf+\xa5\xf1;\x16\xd5\xbd\x8d\x8d\x92\xa4K\xc0B\xd5\xf7\xbf\xabV\xab/'qW\xca\xe5\xdc\x17\x95\xca\x0ff\xf6)\xd1w\xfcq'\xffO\xfc\xceW|\x7f,4[D:\x1a\xb7\xd7\x1b\x82\xbfb'\xcf#\x8d\x125\xa0;2\x9b)\x14\x0a\x89\x85\xf7\x9f\x04\xc0\xe3\x1f\xf2\x8c`\x0c\xc8a\x16\xf5\x09\xa9n\xf0\x8b\xa4\xdav\xabu--\xe7=\xf4\xd0\xc3\xbf\xf1\x0fx\xe5N\xf2\x11\xe4iB\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02J\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10\x14\x1a8\xc77\xd0\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x01\xaeIDATx\xda\xed\x9bI\x92\xc3 \x0cE#]\xdc\xf6\xc9\xd3\xbb\xaeT\x06&\xe9\x7f\x09\x8c\xd6]2\xef!h \xf0x\xec\xd8\xb1\xe3\xce!\xcc\x8f\x9d\xe7\xf9l\xfc;YB@+p\xa4\x10\xc9\x0a\xcd\x92!\xb3\x80\xa3D\xc8\x8c\xf0\x9e\x12dFpO\x112;\xbcU\x82\xcc\x0en\x15!+\xc1\x8fH\x90\xd5\xe0{%\xe8^\x0a/\xd8\xfb=U V\xf8\xe38\xfes\x5c\xd7E\x11\xf5\xfa\xcd\xdawk\x12\xd4\xbba\xef\x8dC\xc3[C\x11\xa5\x8f\x920\x92\xb7\xc6\xa0\xa8q\xef-\xc1\x92\xaf\xc4b\x1e\x02\xa5\xf1\xe7%\xa1\x94\xc7:\xef\x88W\xef\xa3\x1a\xe9\x99\xf7\xdb\x84\xe86\x09\x22*\x01\xd9\xf3\x90\xff\x02\x9e\x12\x18\xf0_\x87\x80\xc7\xa2\xc7\xdax$\xfc\xfb0\x80,\x85-\x95\xc0\xeay\xf8^`D\x02\x1b\x1e\xbe\x19\xea\x91\x10\x01\xff1\x07\xa06=586\xfc\xeb<@\xd9\x0e\x8f\xce\x09\x8c\xcd\x15\xed<\xa0\x17\x86\xb5\xb3\xa4\x1e\x88\xb4B\xb1\xe0\xe9\x02Z\xe0\x98\xf0!\x02,\xeb\x80\xe9\x05\xb4\xc21%h6x\xb6\x04\x8d\x86g\x9c'\x84\x0ah\x81\x8f\x94\x00\xd9\x0d\x8e\xf6<cQD\xd9\x0d\x8e\xc2DT\x82f\x1a\xf3\x11\x124\x13|\x84\x04\xb7CQ\xc4\x18\xf6\xce\x07=\x14EL`\x8cJ\xd0\xac\xf0,\x09R(\x97g4\xbc\xe7w~\xfdH\x1ar&\x98!_U\x80\xe5\xe6\x15\xaa\xb1\xa3yK,\x9a\xbd\xe7\xd1\xf9\xcd\x17$\xb2G\xad\x92\xf7\x15\x99\x8ed\xfb\x96\xd8\x8a\xb1/J\x0e$\xbf\xefU\xd9\xcc\x22h\x97\xa53J\x08\xb9.\x9fE\x82\xf5\xd1\xc4~2\x03h\xd8=\x1fM!eL\xf5l\xceC\x08\xf3\xe1\xe4\x8e\xbb\xc7\x1f\xfe\x88Z\xe2\xcd\xef\x1cI\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xac\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x07\x00\x00\x00?\x08\x06\x00\x00\x00,{\xd2\x13\x00\x00\x00\x06bKGD\x00\xb3\x00y\x00y\xdc\xddS\xfc\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10.\x14\xfa\xd6\xc4\xae\x00\x00\x009IDAT8\xcbc` \x06\xc4\xc7\xc73\xc4\xc7\xc7\xa3\x881aS\x84S\x12\xaf\xce\x91(\xc9\x82\xc4\xfe\x8f\xc4f\x1c\x0d\xa1Q\xc9Q\xc9QI|\x05\x06\xe3h\x08\x91*I>\x00\x00\x88K\x04\xd39.\x90?\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xb6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x18\x00\x00\x00\x11\x08\x06\x00\x00\x00\xc7xl0\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b,\x0d\x1fC\xaa\xe1\x00\x00\x006IDAT8\xcbc` \x01,Z\xb4\xe8\xff\xa2E\x8b\xfe\x93\xa2\x87\x89\x81\xc6`\xd4\x82\x11`\x01#\xa9\xc9t\xd0\xf9\x80\x85\x1cMqqq\x8c\xa3\xa9h\xd4\x82ad\x01\x001\xb5\x09\xec\x1fK\xb4\x15\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02B\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xb3\x00y\x00y\xdc\xddS\xfc\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10\x17;_\x83tM\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x01\xa6IDATx\xda\xed\x9b\xdb\x0e\xc3 \x0cC\x9bh\xff\xdd\xf6\xcb\xb7\xb7i\x9avIK\xec\x98B^7Q|p(\x85\xb0,3f\xcc\x189\x8c\xf9\xb0m\xdb\xee\xc1\xff\xd9%\x00D\x05W\x021U\xd1,\x18\xd6\x8bp\x14\x08\xebQ|&\x04\xebQx&\x08\xeb]|+\x04\xeb]x+\x08\xbb\x92\xf83\x10\xecj\xe2\x8fB\xb8Uvr]\xd7g'\xf7}/\x01lU\xa3\xff*\x1e\x05!\xe2\x02S\x11_\x05\xc1+m\x7f\xe6wj\x0ad\x8f\xfe\x11q\x99N\xf8\xe5\x02S\x14\xcf\x84\xe0\xd5\xb6\xff%\x92\x91\x0e\x86\x1e\xfd\xa8x\xc6\xc4\xf8\xc9\x05\xae2\xf2UNp%\xdbW@0\x84\xfd[\xed\x8cL\x87\xf74p\x85\x91\xaft\x82\xab\x89gCpE\xf1L\x08\x96\x91\xff\xe8WXv\xfb\xaf\xf3\x80+\x8e<\xd3\x09\xae.\x1e\x0d\xc1{\x10\x8f\x84\xe0\xccN*\xb6O]\x07(\xb6\xefj9\xc9N;W\xcbI\xf6\x9c\xe3\xc8\x9c\xcc\x82\x80\x9cpS\xe6\x00$\x04\xf4\xdb&\xf5k0\xbb\xb3\x08\xf1\xd0\xaf\xc1L'\xb0\xd6\x19\xd4u@\x14\x02s\x91\x05\xd9\x11j\x81\xc0^aB7E\x8f\x8aA\x8b\xa7o\x8a\x1eqB\xc5\xb7\x05\x1c@\x14B\x95\xf8\xaf)\x90\x99\x06-\xeb\x81\xcb\x9c\x0c\x9d\x11\xc3\xaa\x17\xa0\x1e\x8eF\x9d\xc0<\x22\xa7\x1f\x8f\xff\x13\xc7\xae\x14))\x90\xf8\xe6\x04\x84\xf8\x7f\x05\x12e%2\xef\x10*\xc4\x87\x01 !\xa0\x22Z%\xe6\xcb\xe01\x0b%O4>n\xa9\xac2\x08Z\xb1\xb4\x22\x84\x92ry\x15\x08\xad\x97&\xe6\x95\x19@\xc7\xc6\xbc4\x85\x84\xd1\xd5\xb5\xb9\x0c \xcc\x8b\x933F\x8f\x07S!r\xe7\x176+c\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02\xd8\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x02UIDATX\x85\xed\x95MOSQ\x10\x86\x9f\xb9\x1a\x12\xefO\x10\x0d\xc1\xb0\x12M\xb0\xf1\x0f\xc0\x06\xe3\x06HLw\xd0\x0f\x16l\x8d\x01,\xaeXh\x82\x05\xff\xc2=\xad\xec\xae\x89\x16W~,\xc4\xad\xf1\x8bhb\x0c!\xa4\xb1\x86?\xd0\x86\x86&}]\xb4!\xc6p[.\xb0\xb3\xefv\xe6\xcc<g\xce\x99\x19\xe8\xa9\xa7\xff]\x16\xc79\x0c\xc3\xbe\xfdjuJf\x93\x06\x09\xa0\xbfm\xaa`\xf6YP\xf2}\xbf\x94L&\x0f\xce\x1c\xa0\x18\x04w0\xcb\x03\x83\x06\xdf\x04\x9b2\xab\x00x\xcdf?f\xa3\x82\xeb\xc0\x8e\xc1\xe2L&\xf3\xfcL\x00\xc20<\xb7_\xab\xe5\x81{\x06\xaf\xac\xd9\xccM\xcf\xcen\x1d\xe5\xeb\x9c\x1b\xf1`\x05\x18\x07Vw\xcb\xe5\xdc\xf2\xf2r\xb3S\xfc\xf3\xdd\x00\xda\xc9\xefJZHe\xb3k\x9d|3\x99\xccW\xe0V\xd1\xb9\x05`ep`\x00`\xb1\xd3\x99\x8e\x15h\x97\xfd\x99\x99\xcd\xcf\xa4\xd3O\xba\xc1\xfe\xadB\xa1\xb0h\xd2c\x0f\xa6\xa63\x99Rl\x800\x0c\xfb\xea\xb5\xda\x0fI?S\xd9\xec\xed8\xc9\x0f!\x9c{cf\x83\x17|\x7f8\xeaczQ\x87\xf7\xab\xd5)\xc1\x15OZ:Ir\x00\xf3\xbc\xfbHC\xf5Zm\x22\xca'\x12@f\x93\xc0V\xd4\x87;\x8eR\xa9\xd4\x17\xcc\xbe\x03\xf1\x01\x0c\x12&\xbd?i\xf2CI\xef\x047\xa3\xcc\xd1]`vQP95\x00\xfc\xc6\xac?\xca\x18Y\x01\x00\x99\xc5\x9a\x94G\xc9\xc0\x90\x22gA4\x80\xb4g\xd2\xa5\xd3\x02\xa8u\xfb\xbd({\xa7'\xf8\x08\x8c\x9e\x1a@\x1a3\xf8\x10e\x8f\xee\x02(!]s\xce\x8d\x9c4\xf9z\x10$\x0c\xae\x22\xbd\x8c\x0d\xe0\xfb~\x09\xd8i\xcf\xf6\xd8\x92d\xcd\xd6\xf2\xda\xae7\x1a\x1b\xb1\x01\x92\xc9\xe4\x01\x9e\xb7\x00\x8c\xb7g{,\x15\x9d\xcb\x01c2\x9b\x9f\x9b\x9bk\xc4\x06\x00H\xa5R/\x80U`\xe5\xb8\x10\x92\xac\x10\x04Kf\xf6\x10\xc8\xa7\xd3\xe9\xc8\xf2w\x05\x00\xd8-\x97s\x92\xd6\x80|\xd1\xb9\xd7\xc5b\xf1F\x94\xefz\x10$\x9e\x16\x0ao\xcd\xec\x11\xadu\xfc\xa0[\xfcc\xf7\xf9\xbas\x93M\xb3U\xa4\xa1\xf6x\xdd\x14\xfcj\x07\xb9\x8c4\x0a\x0c\x03\xdb2\x9b\xefv\xf3\xd8\x00p\xb8!'\x04\x93@\x02\xb3\xd6\x9c\x90*\x06\x9f$\x95\xea\x8d\xc6F\xa77\xef\xa9\xa7\x9e\xfe\xd5\x1f>\xd4\xefD\x0d\xbc\xffe\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x9f\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x14\x1f\xf9#\xd9\x0b\x00\x00\x00#IDAT\x08\xd7c`\xc0\x0d\xe6|\x80\xb1\x18\x91\x05R\x04\xe0B\x08\x15)\x02\x0c\x0c\x8c\xc8\x02\x08\x95h\x00\x00\xac\xac\x07\x90Ne4\xac\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xd0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x01MIDATX\x85\xed\xd7MN\xc2@\x18\xc6\xf1\xff[\x08\x08\xea\x01\xd0+\x88\x09[\xcf!\xbb\xca\xd8\x1aI\xe0>bBBiI\x97x\x0c\xd7\x84p\x07q\xef\x07\x02\x81\xd7\x85\xd4\x10\xc0\xdd\x10\x13\xed\xb3\x9b\xc9\x9by~\x93n:\xf0\xdf#\x9bk\xcf\x98k\xa0\x01\x94\x81\x03K=\x1f\xc0HDZA\x18F\x80\xee\x02\x88gL\x08\xd4\x80)0\x00^-\x01\x8e\x80\x0a\x90\x07\xba\xdd(\xbaI\x10\xdf\x00\xcf\x18\x0f\x08\x04\x1e\xb3\x8bE\xb5\x1d\xc7cK\xe5\x00\xd4]\xb74w\x9c>\x22\x17\x02&\x88\xa2\x1e\x80\xb36\xd3\x00\xa6K\x91K\xdb\xe5\x00\xed8\x1eK6[\x05f*\xd2L\xf6\xd7\x01g\xc0 \x0c\xc3g\xdb\xe5I\x82 xBd\x80jy\x17\xa0\x80\xea\xfb\xbe\xca\xbf\xb3\x5c\xbe\x01\xc5]\x80_I\x0aH\x01) \x05\xa4\x80\x14\x90\x02R\xc0:`\x82H\xf1\xc7Ik\x8d\xce!0\xd9\x02(\x8c\x80J\xdduK\xfb\xea\xae\xd5j\xa7\xa8V\x80\xe1\x16\xc0\x11\xb9\x07\xf2\xf3L\xe6\xc1\xf7\xfd\x93}\x94gD\xfa@NEZ\xc9\xfe\xe6\xc3\xa4\x03x\xc0l\xf5\xf7\xfab\xa5]\xe4xu\xf3\x9cB'\x8c\xa2[6\x1f&\xc9\xa8o\xcc\x95\x8a4Q=\x07\x0aV\x00_\xdf|\x88\xea]\xb7\xd7\x8b-\x9d\xf9G\xf2\x09>pdA\x95\x87\xdfi\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xc3\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x09.7\xffD\xe8\xf0\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x00'IDATx\xda\xed\xc1\x01\x0d\x00\x00\x00\xc2\xa0\xf7Om\x0e7\xa0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80w\x03@@\x00\x01\xafz\x0e\xe8\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xd0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x01MIDATX\x85\xed\x97;N\xc3@\x14\x00\xe7EQ\xc2\xf7\x00\x81+\x00R\xeeB\xca\x8d\xedX\x14p\x1fBe\x99\x8d)\xc3\x1dh\xa8\xa3(w \xf4|B>\xf2\xa3p\x8c\x8cL\xb9\x16\x12x*[Zyf%\x17\xef\xc1\x7fG\x8a/\xaa*6\x8e\xfd\x86\xc8\xa5\xc2)\xb0\xe3\xc8\xf3!0\x03\x86\xc6\xf7\xad\x88h)@U%\x89\xe3[\x15\xe9\x03K`\x82\xc8\xab\x13\xbd\xea\x01\xd0\x05\xda\x88\xc4}\xcf\x0b\xf3\x88f~\xc6\xc6\xb1/\x99\xfc\xb1\xd1l\xf6\x8c1s'\xf2-I\x92t\xd2\xcdf\x8cj`\xad}\x00F\x00\x8d\xfc@C\xe4\x12X\xa6p\xeeZ\x0e`\x8c\x99o\xd2\xb4\x07\xacD\xf5\xea\xcb\x9b?(\x9c\x00\x93 \x08\x9e]\xcbs\xc20|\x02&d\xff\xd7\xf7\x00`\x17x\xafJ^\xe0\x0d\xd8\xfb)\xe0W\xa8\x03\xea\x80:\xa0\x0e\xa8\x03\xea\x80:\xa0\x0e(\x06,(L*\x15\xb2\xbfu\x95\x02f@7I\x92NUfk\xed1\xd9x>-\x05\x08\xdc\x00\xedt\xbd\xbe\x8f\xa2\xe8\xa8\x12y\x9a\x8e\x81\x96\xc0\xb0\xe0\xcdPU\x19Y\x1b\xa1\x1a\x00+\xb2\xc5\xe4\xc5\x89]\xf5\x90\xec\xe6-\x85\xc8\xf3\xfd\x8b|1)\xaff\xd6\x9a\xed\xdc~F6)\xbb`\x01LQ\xbd\xf6\x06\x83;G\xdf\xfc#|\x02\x90\xc4u0\xa38\xd1\xd4\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xef\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b*2\xff\x7f Z\x00\x00\x00oIDATx\xda\xed\xd0\xb1\x0d\x000\x08\x03A\xc8\xa0\x0c\xc7\xa2I\xcf\x04(\xba/]Y\x97\xb1\xb4\xee\xbes\xab\xaa\xdc\xf8\xf5\x84 B\x84(\x88\x10!B\x14D\x88\x10!\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22DA\x84\x08Q\x10!B\x84(\x88\x10!B\x14D\x88\x10!\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22DA\x84\x08Q\x10!B\xfc\xaa\x07\x12U\x04tV\x9e\x9eT\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02V\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10\x14-\x80z\x92\xdf\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x01\xbaIDATx\xda\xed\x9b[\x92\x02!\x0cEM\x16\xa6\x1b\xd0\xd5\x8e\x1b\xd0\x8d\xe9\x9fe9\xda<\x92{\x13h\xf2=\x95\xe6\x1c\x1eC\x10\x0e\x87\x15+V\xec9\x84\xf9\xb1\xbf\xe3\xf1Q\xf3w\x97\xfb]\xa6\x10P\x0b\x1c)D\xb2B\xb3d\xc8(\xe0(\x112\x22\xbc\xa7\x04\x19\x11\xdcS\x84\x8c\x0eo\x95 \xa3\x83[E\xc8L\xf0=\x12d6\xf8V\x09\xba\xb6\xc2\x13\xf6~\xcb(\x10+\xfc\xf9v{\xe5\xb8\x9eN\x14Q\xef\xdf,}\xb7$A\xbd\x1b\xf6\xd984\xbc5\x141\xf4Q\x12z\xf2\x96\x18\x145\xef\xbd%X\xf2m\xb1\x98\xa7\xc0\xd6\xfc\xf3\x92\xb0\x95\xc7\xba\xee\x88W\xef\xa3\x1a\xe9\x99\xf7\xdb\x82\xe8\xb6\x08\x22F\x02\xb2\xe7!\xff\x05<%0\xe0\xbfN\x01\x8fM\x8f\xb5\xf1H\xf8\xcfi\x00\xd9\x0a[F\x02\xab\xe7\xe1\xb5@\x8f\x046<\xbc\x18j\x91\x10\x01\xffo\x0d@\x15=%86\xfc\xfb:@)\x87{\xd7\x04FqE;\x0fh\x85aU\x96\xd4\x03\x91Z(\x16<]@\x0d\x1c\x13>D\x80e\x1f0\xbc\x80Z8\xa6\x04\xcd\x06\xcf\x96\xa0\xd1\xf0\x8c\xf3\x84P\x015\xf0\x91\x12 \xd5`o\xcf36E\x94j\xb0\x17&b$h\xa69\x1f!A3\xc1GHp;\x14E\xcca\xef|\xd0CQ\xc4\x02\xc6\x18\x09\x9a\x15\x9e%\xe1g\x82\xdai\xc0\xaa\xe7\xad\xdf\xf9\xf5#i\xc8\x99`\x86|E\x01\x96\x9bW\xa8\xc6\xf6\xe6\xddb\xd1\xec=\x8f\xceo\xbe \x91=J#y]\x91\xa9M\xb6n\x89M\x1a\xeb\xa2dk\xf2]_\x95\xcd,\x82vY:\xa3\x84\x90\xeb\xf2Y$X\x1fM\xac'3\xde\x0d\xdb\xed\xa3)\xa4\x8c\xa1\x9e\xcdy\x08a>\x9c\x5c\xb1\xf7x\x02Q\xa0Z\x91w\xd2\x02#\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xec\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x01iIDATX\x85\xed\x97;N\xc3@\x10\x86\xbf\xb1\xa2\x84\xe7\x01\x02W\x00\xa4\xdc\x85\x94\x8e\xedD\x14p\x1fBe-\x1bS\x86;\xd0PGQ\xee@\xe8y\x84<\xe4\xa1p\x8c\x8c,%\x056\x05\xf8\xafv\xb5#\x7f\x9f\xad\x95<\x03\xff=\x92\xdd\xa8\xaaXc|G\xe4R\xe1\x14\xd8)\x88\xf3!0\x01\xfa\xae\xef[\x11\xd1\x9c\x80\xaaJd\xcc\xad\x8at\x8090B\xe4\xb5\x10\xbc\xea\x01\xd0\x02\x1a\x88\x98\x8e\xe7\xf5R\x89ZZc\x8d\xf1%\x81?:\xb5Z\xdbu\xddi!\xf0u\xa2(j\xc6\xab\xd5\x10\xd5\xc0Z\xfb\x00\x0c\x00\x9c\xb4\xc0\x11\xb9\x04\xe61\x9c\x17\x0d\x07p]w\xba\x8a\xe36\xb0\x10\xd5\xab/n\xbaP8\x01FA\x10<\x17\x0dO\xd3\xeb\xf5\x9e\x80\x11\xc9\xfd\xfa.\x00\xec\x02\xefe\xc13y\x03\xf6\xd2MmC!\x00\xd6\x18\xddV\xb3)^\x10\xc8\xa6sg\xd3\xe1o\xa4\x12\xa8\x04*\x81J\xa0\x12\xa8\x04*\x81\xad\xfd\xc0\xb6\xff\xf9O\x93\xfd\x0232\x9dJ\x89\xd9_\xb3r\x02\x13\xa0\x15EQ\xb3,\xb2\xb5\xf6\x98\xa4=\x1f\xe7\x04\x04n\x80F\xbc\x5c\xde\x87axT\x0a<\x8e\x87@]\xa0\x9f\xe1&QU\x19X\x1b\xa2\x1a\x00\x0b\x92\xc1\xe4\xa5\x10\xba\xea!\xc9\x9b\xd7\x15B\xcf\xf7/\xd2\xc1$?\x9aY\xeb\xae\xfb\xf63\x92N\xb9\x88\xcc\x801\xaa\xd7^\xb7{W\xd03\xffH>\x01\xac\x18zV\x83\xd7\xe8n\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1d\x00\xb0\xd55\xa3\x00\x00\x00*IDAT\x08\xd7c`\xc0\x06\xfe\x9fg``B0\xa1\x1c\x08\x93\x81\x81\x09\xc1d``b``4D\xe2 s\x19\x90\x8d@\x02\x00d@\x09u\x86\xb3\xad\x9c\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x96\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\x0d\x1bu\xfe1\x99\x00\x00\x00'IDAT\x08\xd7e\x8c\xb1\x0d\x00\x00\x08\x83\xe0\xff\xa3up\xb1\xca\xd4\x90Px\x08U!\x14\xb6Tp\xe6H\x8d\x87\xcc\x0f\x0d\xe0\xf0\x08\x024\xe2+\xa7\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1c\x1f$\xc6\x09\x17\x00\x00\x00$IDAT\x08\xd7c`@\x05\xff\xcf\xc3XL\xc8\x5c&dY&d\xc5p\x0e\xa3!\x9c\xc3h\x88a\x1a\x0a\x00\x00m\x84\x09u7\x9e\xd9#\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa5\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x02\x04m\x98\x1bi\x00\x00\x00)IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0c\xff\xcf\xa3\x08\x18220 \x0b2\x1a200B\x98\x10AFC\x14\x13P\xb5\xa3\x01\x00\xd6\x10\x07\xd2/H\xdfJ\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x0b\x17\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00?\x00\x00\x00\x07\x08\x06\x00\x00\x00\xbfv\x95\x1f\x00\x00\x00\x87zTXtRaw profile type exif\x00\x00x\xdaU\x8e\xd1\x0d\xc40\x08C\xff\x99\xe2F @L\x18\xa7\xaa\x1a\xe96\xb8\xf1\x0f\x94Vm\xdf\x87\xb1,d\xa0\xe3\xf7\x9d\xf4)\x1a\x0bY\xf7\x81\x008\xb1\xb0\x90-\xcd\xe0\x8527\xe1V3uqNm\xe9\xe4\x8eIe\x19\xc4p\xb6{\xd1\xce\xfc\xa2+\x06\xa6\x9b;:v\xec\x92\xedr\xa8\xa8\xa4VQ\xb5r\xbd\x11\x8fk\xf3\xfa\xe8\x9d\xb3\xbf\xcb\xe9\x0fH!,K\xed~\xc6\xe4\x00\x00\x0a\x00iTXtXML:com.adobe.xmp\x00\x00\x00\x00\x00<?xpacket begin=\x22\xef\xbb\xbf\x22 id=\x22W5M0MpCehiHzreSzNTczkc9d\x22?>\x0a<x:xmpmeta xmlns:x=\x22adobe:ns:meta/\x22 x:xmptk=\x22XMP Core 4.4.0-Exiv2\x22>\x0a <rdf:RDF xmlns:rdf=\x22http://www.w3.org/1999/02/22-rdf-syntax-ns#\x22>\x0a  <rdf:Description rdf:about=\x22\x22\x0a    xmlns:exif=\x22http://ns.adobe.com/exif/1.0/\x22\x0a    xmlns:tiff=\x22http://ns.adobe.com/tiff/1.0/\x22\x0a   exif:PixelXDimension=\x2263\x22\x0a   exif:PixelYDimension=\x227\x22\x0a   tiff:ImageWidth=\x2263\x22\x0a   tiff:ImageHeight=\x227\x22\x0a   tiff:Orientation=\x221\x22/>\x0a </rdf:RDF>\x0a</x:xmpmeta>\x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                           \x0a<?xpacket end=\x22w\x22?>@\x00Zq\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00/IDAT8\xcbc`\x18\x05#\x130\xc2\x18\xf1\xf1\xf1\xa4\xe8\xfb?\x98\xfdB\x0cX\xb8p!\x03\xd3H\x8e\xf9\x11\xe9\xf9\x85\x0b\x17\x8e\xe6\xf9\x11\x0d\x00\x8bl\x05\xe9)K\xfc\x15\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x0b\x1f\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00\x10\x08\x06\x00\x00\x00\xa6\xe7y)\x00\x00\x00\x87zTXtRaw profile type exif\x00\x00x\xdaU\x8e\xcb\x0d\xc3@\x08D\xefT\x91\x12\xf8\xed\xb0\x94\x13Y\xb6\x94\x0eR~@k\xcb\xf1;\xc0h\xb4\xfb\x04\xed\xdf\xcfA\xafFX\xc9GL$\xc0\x85\xa7\xa7\xbe+L^\x18\xb3(K\xef\x9a\x8bs\x9bT\xd2\xbb&\xd3\x15\x903\xd8\xef\x87~\xf6\x17\xc30q\x84G``\xc3\xa6e\xd7\xdd\xd4\xb4f\x8b\xda\xca}F\xfeI\xae\xdf\xf6\xec\xe5\xe9f\xfa\x01?{,\x10\xd82\x95\xc4\x00\x00\x0a\x02iTXtXML:com.adobe.xmp\x00\x00\x00\x00\x00<?xpacket begin=\x22\xef\xbb\xbf\x22 id=\x22W5M0MpCehiHzreSzNTczkc9d\x22?>\x0a<x:xmpmeta xmlns:x=\x22adobe:ns:meta/\x22 x:xmptk=\x22XMP Core 4.4.0-Exiv2\x22>\x0a <rdf:RDF xmlns:rdf=\x22http://www.w3.org/1999/02/22-rdf-syntax-ns#\x22>\x0a  <rdf:Description rdf:about=\x22\x22\x0a    xmlns:exif=\x22http://ns.adobe.com/exif/1.0/\x22\x0a    xmlns:tiff=\x22http://ns.adobe.com/tiff/1.0/\x22\x0a   exif:PixelXDimension=\x2264\x22\x0a   exif:PixelYDimension=\x2216\x22\x0a   tiff:ImageWidth=\x2264\x22\x0a   tiff:ImageHeight=\x2216\x22\x0a   tiff:Orientation=\x221\x22/>\x0a </rdf:RDF>\x0a</x:xmpmeta>\x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                                                                                                    \x0a                           \x0a<?xpacket end=\x22w\x22?>'q\xef\x0e\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x005IDATX\xc3\xed\xd5\xb1\x0d\x000\x08\x041\xc8\xa2\xcc\xc6\xa4I\x9b\x1d\xde\xee(\x91@WE\xb6\xfe\x87\x99\xb9I\xcb\xefn\x9f\xf4\x0b8\x9e\x00\x90A\x19\x94A\x80H\x0f\xc6\x9d\x08\x0b\xaacu(\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xe0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b)\x1c\x08\x84~V\x00\x00\x00`IDATx\xda\xed\xd9\xb1\x0d\x00 \x08\x00AqP\x86cQ\xed\x8d\x85%\x89w\xa5\x15\xf9HE\x8c\xa6\xaaj\x9do\x99\x19\x1dg\x9d\x03\x11E\x14\x11\x11E\x14QDD\x14QD\x11\x11QD\x11EDD\x11E\x14\x11\x11E\x14\xf1[\xd1u\xb0\xdb\xdd\xd9O\xb4\xce\x88(\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\xcf6\xcei\x07\x1e\xe99U@\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02\xf8\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x02uIDATX\x85\xed\x96\xcdN\x13Q\x18\x86\x9f\xaf\x15\xd22x\x03VMiX\x89\xa6?\xf1\x06 &\x1a7\x94\x84\xd9\xb63\xc4\x0b0F\x104Q\x16.H\xd1\xb8rC\xb4t\xd8\x92\x98\xe2\xca\xb8\x117,\x8c\xda6\x12\xc0\x10@\x03\x86\x0b\xc0T\xa3q>\x17\xb4\xd1D\xa6e\x0a;\xfbl\xbf\xf7\x9c\xf7I\xe6\xcc\x99\x816m\xfew\xc4O\xd84\xcd\xce\xeepxHD\xd2@J!\x02\x80\xea\x0e\x22\xef\x05\x8a{\xd5jq~~\xfe\xc7\xb1\x0b\xd8\x99\xcc\xb0\x8a\xe4\x04z\x80\x0f\xa2\xba\xa8\x22;\xb5q\x04\xe8\x07.\x00\x1b*2V(\x14\x9e\x1d\x8b\x80i\x9a\xc1\x93\x86\x91S\xd5\x1b\x02/\x08\x06\xc7\xf3\xf9|\xe5\xa0\xaceY\x09\x81)T/\xab\xeat4\x16\x1b\x9f\x9c\x9ct\x1b\xed\x7f\xa2\x99@\xad\xfc:0\x9aw\x9c\x07\x8d\xb2\x85B\xa1\x0c\x5c\x19\xb1\xacQ`\xea\xd3\xe6&\xc0X\xa35\xc1FC;\x93\x19\x06\x1e\x09\x8c\xce:\xce\xc3f\xb2uJ\xe5\xf2R2\x91\xf8.\x22\xf7\x12\xc9d\xa5\x5c.\xafye=\x1f\x81i\x9a\x9d\xdd]]\xab\xc0\xc7Y\xc7\xb9z\xd8\xf2\xbf\xb1\xb3\xd9\x97@\xcf\xd7j\xb5\xcf\xeb`\x06\xbc\x16w\x87\xc3C@L\x82\xc1\x89V\xca\x01\x02\xaa\xb7\x80^\xc30\x06=3^\x03\x11I\xa3Z\xf1:p\x87\xe1\xe9\xdc\x5c\x09XF\xd5\xbf\x00\x90B\xe4u\xab\xe5uD\xf5\x95\xa8^\xf4-\xa0pJ\xfe\xbc\xe7-\xe3\xc2\x17D\x22\xbe\x05\x00T\xd5\xd7My`A  \xfb\x1e\xfe\x05vE\xf5\xf4Q\x05T5\x82\xean+\x02oU\xa4\xff\xa8\x02\xc0\x80\xc0\x1b\xdf\x02\x02E\xe0\xbceY\x89V\x9bm\xdbN\x01\xe7\x14\x9e\xfb\x16\xd8\xabV\x8b\xc0\x86\xc0T\x8b\xfd\x22\xae\x9b\x03\xd6;B\xa1\x05\xaf\x90\xe7U\xbc\xb2\xb2\xf2+\x15\x8fo\x03wR\xc9d\xb5T./\xf9i\xb7\xb3\xd9\x09\xe0\x9a\xc0\xc8\x93|~\xd5\xb7\x00@\xa9RYK\xc4\xe3\x06p7\x95L~;\xa4\x84\xd4\xca\xef\x8b\xc8t\xdeq\x1e7\x0a7\xfd\x1aFc\xb1\xf1\xcf[[\xaa\xaa9+\x9b\xbd\x14T\x1d\xaf\xddp\xff`\xdbvJ\x5c7\xa70 \x22\xb9\xb3\xd1\xe8\xed\xa6\xb6\xcd\x02u,\xcbJ\x8b\xea4\xd0\x0b,\x03\x8b\xc0vm|\x86\xfd\x1f\x92>`]\xe0f\xdeq<\x0f^K\x02\xb0\xff\x854\x0ccP\x5c7\x8dH\x0a\xa8\xdf\x13;\x0a\xefD\xb5\xd8\x11\x0a-\xcc\xcc\xcc\xfc\xf4\xb3o\x9b6\xff7\xbf\x01J7\xdd\xdd\x8c\xf1\x82j\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x93\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\x0c+J<0t\x00\x00\x00$IDAT\x08\xd7c`@\x05\xff\xff\xc3XL\xc8\x5c&dY&d\xc5p\x0e##\x9c\xc3\xc8\x88a\x1a\x0a\x00\x00\x9e\x14\x0a\x05+\xca\xe5u\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b\x0e\x16M[o\x00\x00\x00*IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x81\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x01\x03\x00\x00\x00%=m\x22\x00\x00\x00\x06PLTE\x00\x00\x00\xae\xae\xaewk\xd6-\x00\x00\x00\x01tRNS\x00@\xe6\xd8f\x00\x00\x00)IDATx^\x05\xc0\xb1\x0d\x00 \x08\x04\xc0\xc3X\xd8\xfe\x0a\xcc\xc2p\x8cm(\x0e\x97Gh\x86Uq\xda\x1do%\xba\xcd\xd8\xfd5\x0a\x04\x1b\xd6\xd9\x1a\x92\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xdc\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00@\x08\x06\x00\x00\x00\x13}\xf7\x96\x00\x00\x00\x06bKGD\x00\xb3\x00y\x00y\xdc\xddS\xfc\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10-\x19\xafJ\xeb\xd0\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x00@IDATX\xc3\xed\xce1\x0a\x00 \x0c\x03@\xf5\xa3}[_\xaaS\xc1\xc9\xc5E\xe42\x05\x1a\x8e\xb6v\x99^%\x22f\xf5\xcc\xec\xfb\xe8t\x1b\xb7\x1f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf06\xf0A\x16\x0bB\x08x\x15WD\xa2\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xf0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x07tIME\x07\xe1\x05\x0d\x0a:+\xaf\xc4\x97\xc5\x00\x00\x00}IDATX\xc3c`\x18\xe9\x80\x11\x85\xf7\xff?\xa3\xed\xfaW\xffhi\xe1\xe1@1&\x06F\xc6\xff\x98\x0e\xa0\x83\xe5\xd8\x1c\x01w\x80\xed\xba\x97\xffQ\x14\x05\x893R\xd3R\x5c\xe63au!\x95-\xc7g&\x13=,\xc7g6\xd3@\xe7\x82Q\x07\x8c:`\xd4\x01\xa3\x0e\x18u\xc0\xa8\x03F\x1d0\xea\x80Q\x070\x11j\xbd\xd2\xb2e\x8c3\x04h\xe1\x08\x5cf\x0e\x9e\x8e\x09\xdd\xbaf4l\xf6\x0fM\x00\x00_934+ \x00\xc5\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02V\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdf\x04\x19\x10\x15\x00\xdc\xbe\xff\xeb\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x01\xbaIDATx\xda\xed\x9b[\x92\x02!\x0cEM\xd67.H\x17\xa0\x0b\xd2\xfd\xe9\x9fe9\xda<\x92{\x13h\xf2=\x95\xe6\x1c\x1eC\x10\x0e\x87\x15+V\xec9\x84\xf9\xb1\xdb\xe9\xf4\xa8\xf9\xbb\xe3\xf5*S\x08\xa8\x05\x8e\x14\x22Y\xa1Y2d\x14p\x94\x08\x19\x11\xdeS\x82\x8c\x08\xee)BF\x87\xb7J\x90\xd1\xc1\xad\x22d&\xf8\x1e\x092\x1b|\xab\x04][\xe1\x09{\xbfe\x14\x88\x15\xfe\xefry\xe5\xb8\x9f\xcf\x14Q\xef\xdf,}\xb7$A\xbd\x1b\xf6\xd984\xbc5\x141\xf4Q\x12z\xf2\x96\x18\x145\xef\xbd%X\xf2m\xb1\x98\xa7\xc0\xd6\xfc\xf3\x92\xb0\x95\xc7\xba\xee\x88W\xef\xa3\x1a\xe9\x99\xf7\xdb\x82\xe8\xb6\x08\x22F\x02\xb2\xe7!\xff\x05<%0\xe0\xbfN\x01\x8fM\x8f\xb5\xf1H\xf8\xcfi\x00\xd9\x0a[F\x02\xab\xe7\xe1\xb5@\x8f\x046<\xbc\x18j\x91\x10\x01\xffo\x0d@\x15=%86\xfc\xfb:@)\x87{\xd7\x04FqE;\x0fh\x85aU\x96\xd4\x03\x91Z(\x16<]@\x0d\x1c\x13>D\x80e\x1f0\xbc\x80Z8\xa6\x04\xcd\x06\xcf\x96\xa0\xd1\xf0\x8c\xf3\x84P\x015\xf0\x91\x12 \xd5`o\xcf36E\x94j\xb0\x17&b$h\xa69\x1f!A3\xc1GHp;\x14E\xcca\xef|\xd0CQ\xc4\x02\xc6\x18\x09\x9a\x15\x9e%\xe1g\x82\xdai\xc0\xaa\xe7\xad\xdf\xf9\xf5#i\xc8\x99`\x86|E\x01\x96\x9bW\xa8\xc6\xf6\xe6\xddb\xd1\xec=\x8f\xceo\xbe \x91=J#y]\x91\xa9M\xb6n\x89M\x1a\xeb\xa2dk\xf2]_\x95\xcd,\x82vY:\xa3\x84\x90\xeb\xf2Y$X\x1fM\xac'3\xde\x0d\xdb\xed\xa3)\xa4\x8c\xa1\x9e\xcdy\x08a>\x9c\x5c\xb1\xf7x\x02G\xb0[\x07:D>\x01\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f\x0d\xfcR+\x9c\x00\x00\x00$IDAT\x08\xd7c`@\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x03\xcc\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x03IIDATX\x85\xed\x96\xcdk\x5cU\x18\xc6\x7f\xcf\x9d\x99\x98\xe9d\x16\xd2\x9d\xa9\x92\x0e\xa1\x0b\xd3\xd8v\xf0\x1fh\x11\x14+4\x81\xdeU\xca\xcc\xbd\xa5T\x5c\x04Dm:\xd5M\x16.\xe2DW\xb3\x1b\xeax\xa7\x18\xb2\x08\xc8T\xb0\x88\x1b\xeb\xc6\x85h\xf3US\xa4\xb4U\x9aRp%\x990\xa56\xb9\xaf\x8b\xf9h\xc1\xcc\x0cS\xbak\x9e\xdd9\xe79\xef\xfb\xbb\xef}\xef9\x17v\xb5\xab\xe7]\xea\xc5\xec\xban\xdf@<>.i\x0cH\x1b\x0c\x02`\xb6\x8etMP\xa9\xd6j\x95\x85\x85\x85\x7f\x9f9\x80\x9f\xc9\x9c4)/\xd8\x0f\xac\xca\xec\xaaI\xeb\x8d\xe5A\xe0(0\x0a\xdc2i*\x08\x82o\x9e\x09\x80\xeb\xba\x91d\x22\x917\xb3\x0f\x04\xdf\x13\x89\xe4J\xa5\xd2\xf2N^\xcf\xf3\x0e\x0bf0{\xd3\xccf\x87R\xa9\xdc\xf4\xf4t\xd8)~\xb4\x1b@#\xf9\xfb\xc0\xb9R\xb9\xfcy'o\x10\x04K\xc0[\xa7=\xef\x1c0\xf3\xe7\xed\xdb\x00S\x9d\xf6t\xac\x80\x9f\xc9\x9cDZ\x10|T*\x97\xbf\x00\x98\x9c\x9c|asc\xe3]\x83\x09\xd5K\x0ef+\xe68s\xc9d\xb2X(\x14\x1e\x02\xf8\xd9\xec\x14\xf0\x99I\xe3A\x10Tz\x06p]\xb7o`\xcf\x9e\x1b\xc0\x1f_\x95\xcbo\x03\x9c\x99\x98\xd8\xb7\x1d\x8b]\xc1l\x14\x08\x01\xa7a\x0f\x01G\xb0\xe2lm\x1d\xbf87\xb7\xde\x80\xf8\x01\xd8\xbfY\xab\x8d\xb4kLg\xa7I\x80\x81x|\x1cH)\x12\xb9\xd0|\xf2\xedX\xec\x8a\x99\x1d\xdca\xaf\xd3\xa0\x18\x0d\xa3\xd1\xef\x5c\xd7\xed\x03p\xcc\xce\x03\xc3\x89D\xe2D\xbb<m\x01$\x8da\xb6\xdcl\xb8j\xb5z\x16\xb3Qu\xa8\x9a@\x06\xaf\x0d\xc4\xe3g\x01\xbe\xbcti\x11\xb8\x8eY\xef\x00@\x1a\xe9\xa7\xd6\xc8\xec\x14\xf5Rw\x96\x14\x02\xa7ZC\xb3\x1fe\xf6z\xcf\x00\x06/\xe9\xf1w\x8e`\xa4\x0bp\x13\xd4\x914\xd2\x1c\x86p\x0fi\xb0g\x80z,\xeb\xe9\xa4\xdc1\x81\xe3\x88\x0e\x95\xeb\x04p_f\xfbZ0\xf0{\xa7@-Ia\x08\xd7[\xfb\xcc\x061\xbb\xff4\x00\xbf\x9at\xf4\x89\xc0_w\xf173:2\x9b{b\xe6\x98\xe0\x97\x9e\x01\x04\x15\xe0\xa0\xe7y\x87\x01\x92\xc9dQ\xb0b`ms\x83!-m>xP\x04\xf0}?\x0d\xbcj\xf0m\xcf\x00\xd5Z\xad\x02\xdc\x12\xcc\x00\x14\x0a\x85\x87\xce\xd6\xd6q\x07V\x1b\x96\xc7\xaf\xa3\xde\xf9HZ\xde\x0e\xc3w\x1a\x87\x8e\x14\x86y\xe0f\xac\xbf\xffr\xbb<\x91v\x0bkkk\xdb\xe9C\x87\xee\x02\x9f\xa4\x8f\x1c\xa9-.-\xfd|muuc\xf8\xc0\x81R_4\xfa\xb7I{\x05/\x02\x8f\x0c\x16\x1d\x98\xd9\xac\xd5\xde\x9b\x9f\x9f\xff\x07\xc0\xcff/\x00g\x04\xa7/\x96J7\xda\xe5\xe9\xda\xe5^&\x93\x97\xf4\xa1\xa4\x5c)\x08f\xbb\xf9\x01\xf9\xd9l\x0e\xf8T\xd2l)\x08r\x9d\xcc]o\xc3\xa1T*\xf7\xd7\x9d;ffy/\x9b}#b\x96k\x9cp\xff\x93\xef\xfbi\x85a\xde\xe0\x98\xa4\xfc+CC\x1fw\xa5\xedfh\xca\xf3\xbc1\x99\xcd\x02\xc3\xd4?\xb3\xab\xc0\xdd\xc6\xf2\xcb\xd4\x7fHF\x80\x9b\x8d\xdb\xb3m\xe3=\x15\x00\xd4o\xc8D\x22qBa8\x86\x94\x06\x9a\xe7\xc4\xba\xc1o2\xab\xc4\xfa\xfb/\x17\x8b\xc5G\xbd\xc4\xdd\xd5\xae\x9eo\xfd\x07\xb0\xd0<\xea\x1c\xa0\xa5_\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15;\xdc;\x0c\x9b\x00\x00\x00*IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b)\xb3G\xee\x04\x00\x00\x00$IDAT\x08\xd7c`@\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xed\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x01jIDATX\x85\xed\x97\xcbN\xc2@\x14\x86\xbfC\x08x}\x00\xf4\x15\xd4\x84w\x91ei\x0bq\xa1\xef#\xae\x9aq\xa8K|\x077\xae\x09\xe1\x1d\xc4\xbd\x17\xe4\x92\x1e\x17\xa5\xa6\x06\xd8\x98!\x18\xed\xbf\x9av&\xfd\xbeN\xa6\xcd9\xf0\xdf#\xf9\x0bU\x15kLP\x12\xb9T8\x05v\x1cq>\x04\x86@\xc7\x0b\x02+\x22\xba$\xa0\xaa\x12\x1bs\xab\x22M`\x02\xf4\x11yu\x82W=\x00\xea@\x15\x11\xd3\xf4\xfdv&Q\xce\xd6Xc\x02I\xe1\x8f\xa5r\xb9\xe1y\xde\xc8\x09|\x918\x8ek\xc9|\xdeC5\xb4\xd6>\x00]\x80R\xb6\xa0$r\x09L\x128w\x0d\x07\xf0<o4O\x92\x060\x15\xd5\xab/n6P8\x01\xfaa\x18>\xbb\x86gi\xb7\xdbO@\x9f\xf4|}\x17\x00v\x81\xf7M\xc1sy\x03\xf6V\x09l%\x85\xc0\xd6\x05\xca\xeb&\xac1\xban\xee'\xf1\xc3PV\xdd\xdf\xfa\x0e\x14\x02\x85@!\xb0\xf6?\xb0\xee\xbbu\x9d\xad\xef@!\xf0\xab\x04\xc6\xe4*\x95\x0df\x7f\xc1Z\x12\x18\x02\xf58\x8ek\x9b\x22[k\x8fI\xcb\xf3\xc1\x92\x80\xc0\x0dPMf\xb3\xfb(\x8a\x8e6\x02O\x92\x1eP\x11\xe8\xe4\xb8iTU\xba\xd6F\xa8\x86\xc0\x94\xb41yqBW=$}\xf3\x8aB\xe4\x07\xc1E\xd6\x98,\xb7f\xd6z\x8b\xba\xfd\x8c\xb4Rv\x9110@\xf5\xdao\xb5\xee\x1c=\xf3\x8f\xe4\x13\xfb6zV\x11\xde\xcf\xd8\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f \xb9\x8dw\xe9\x00\x00\x00*IDAT\x08\xd7c`\xc0\x06\xe6|```B0\xa1\x1c\x08\x93\x81\x81\x09\xc1d``b`H\x11@\xe2 s\x19\x90\x8d@\x02\x00#\xed\x08\xafd\x9f\x0f\x15\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02\x86\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x07tIME\x07\xe1\x05\x0d\x0b\x097Nl\xc4\x8d\x00\x00\x02\x13IDATX\xc3\xed\x96\xbfkSQ\x14\xc7\xbf\xe7>\x10\xe2}\x0dq(\x82\xa9C\xa5.V\xb1\x06\x07\xd7:I\xad6\x85\xae\xfe\x156\xd1\xba\x0b\xf2\xaa\xa3\x93\xa3\xbb\xbc67m\xd5\xc1\x8a\x9b\xf8\xabX\x11\x09\xd1\xc1\x94T\x84\x1a\xee3\x22-\xef\x1e\x97+tI\x9a\xf7\xc3\xc9w\xd6{\x0e\xe7s~\xdds\x80L2\xf9\xdf\x85\xa2(\x1f~\xd88DG\x8e\xce\x02(\x03(\x01(\xda\xa7\x16\xd8\xbc!\xe1\xf8fg\xdb\xffu\xed\xe4n\xea\x00n=\x98cf\x0f\xc0(\x80\xf7`\xb3N\xc2i\xd9\xe7\x223O\x028CDMA\xa8\xea\xa9\xa1G\xa9\xa4\xe8\xc2\x8b\xae\xe3\xd6\x83{Ri\x96J\xaf\xcaZ\xe7l\x1f\xc8\x09Y\xeb\xacY]/\xf7\xe0\x9dH\x0c`\x9d\x87\xf9\x95`~P\x1b\xa9tE*\x1dJ\xa5\xbd\xa4\xce\xe7\xa4\xd2\xec\xd6\x83\xeb1l\xab\xd6\xb6\x1c\xab\x07l\xc3}$\xa2O?/\x0fM\xc5\x0c\xe0\x093\x8f\xf2\x8fo\xe3\xbd\x1a\xb3g\x8dl\xb7\x9f`\x13.\xc4\xcd 3\xdf\x000F\x85\xe1\x99^:\xfd\x9a\xa4\x0c`\xa3{\xa5\xb0\x11\x17\xa0;\x9d\x7f\x0b6\x9b\x00b\x01\x94\x88\xe8y\x0a\x83\xf4\x0c$\xce\xc7\x018\xc6\xcc\xad\x14\x00\xb6\xf6}X\x91\x00@D\x94\xd4;\x09\x87\x00\x988\x00m6\xe1HR\x00f.\x02hG\x07`\xf3\x0a\xc0d\x0a%\xb8\x08\xe0ed\x00\x12\x8e\x0f\x12\xa7\xddz0\x91\xe0#+\x018ED\xcb\x91\x01\xcc\xce\xb6ODM6\xe1\x9d8\xce\xef\x7f\xd9%\xbb\xbc\x1a9\x87\x96bE \x95\x9e\xb5\x8b\xa5\x12\xd9\xb6\xd6Y\x90J\x1b\xa9\xf4\xd5D\x05\x94J{v\xb1T\x06\x8d\xdc:\x0f\xf3+\xc1\x81\xd9;p]\x9a\xf6\xe7\x9b`s\x17\x80'\x95~,\x95>\xd7\xaf\xe6\xd5\x0f\xbf\x9f\x82\xc4mG\xd0\xe2\xdeV\xf3V\x9a\x07I\x99\x99\x17\x01\x8c\x81\xcd&H\xac\x13\xd1W;j\xc7\xed\xc4\x8c\x03h\x00\x98\xefN\xe7\x97\xff\xcdIV\x18\x9e\x01\x89\xbf'\xd9\xc8\xbe\x93\xec5\x09\xc7\xcf9\xb4\xf4\xfd\x92\xbb\x97]\xbb\x99d2\xa8\xfc\x01\xd2\xac\xe6\x84\xdaGha\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xfc\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x07tIME\x07\xe1\x05\x0d\x0a9\x0e\xcf\xed\x10A\x00\x00\x00\x89IDATX\xc3c`\x18\xe9\x80\x11\x85\xf7\xff?\xa3\xed\xfaW\xffhi\xe1\xe1@1&\x06F\xc6\xff\x98\x0e\xa0\x83\xe5\xd8\x1c\x01w\x80\xed\xba\x97\xffQ\x14\x05\x893R\xd3R\x5c\xe63au!\x95-\xc7g&\x13=,\xc7g6\xd3@\xe7\x02\x16R\xe3\x8eZA?hB`\xd4\x01\xa3\x0e\x18u\xc0\xa8\x03F\x1d0\xea\x80Q\x07\x10l\x0f\xd0\xb2\x8548\xa3\x80\xd2\x16\x10\xa9\xad+&Z4\xc3H1s\xf0tL\xe8\xd65\xa3q\xa2\x1ez\x00\x00\xa3]8e\x19\x919D\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x03N\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x07tIME\x07\xe1\x05\x0d\x0b\x09$\xca\xd2\x85S\x00\x00\x02\xdbIDATX\xc3\xed\x96\xcfKTQ\x14\xc7?\xf7\xf8\x18\x857m\x02\x11\xd2\x16F\xabt\x86A\x8c6&\xa3\x9b\x81\x8c2\x886\xb5\xb6MmBm\xea\x1fH'\xfc\x07\xdc\x9a\xab F\xa1(7\xbd\xc2E\xc8T:\x19\xd2\x0fW\x1a\xc3lB\xc2G\xbcq\xba\xb7\x85wd\x88f\xf4i\xad\xf4\xbb\xba\x87{\xee{\xdf\xfb=\xe7\x9es\xe0\x08G8\xecPa\x9c[^lFZ\x1a\xd5\x15`\x10\xe8\x02Z\xed\xd6\xba6\xbcs\x14\xd9B`\xb2\xc5T\xb4\xf4\xcf\x09$<\xff\xaa\x86\x0c\xd0\x0e|\xd0\x06\xcfQ\xac\xdb\xedV\x0d}@L`\xd5\x11Fs\xbd\xee\x93\x7fB\xe0Z\xeeg\xc3\xe7M\x9d\xd1p\x07x\xae\x0d\xe9\xe5>w\xa9\x06\xc9D\xd90&\x8a\x14\xf0p\xf5G\x90\xf6/\x1d\xd7\x07\x8aQ\xc2\xf3'\xe2\x9e\xff\xab\xfb\xb5?\xbc\xd73q\xcf\x1f\x89{\xfe\xaf\xb8\xe7g\x0e\xa4\x80\x95\xfd\xb1\xc0\xf0b\xd2\x9d\x00\xe8\x99\xf7\x1b7\xb6\xb8\x09\x5c\x17E\xcc\xba\xe6\x05\xa6\xa3\x0e\x93\xf3=n`\xcf\x8ej\x18\x17\xb8\xb2\x98t\xb3\xa1\x09\xd8\x84[\x11\xf8\xb4\x98t/\x00t\xbf\xf6\xdbJ\x9ag@\x0c\xd0\x80Xw\x0d\x88@\xde\x11\x06r\xbd\xee\xba%1\xa7\xa1\xbd\x18\x98\x8eZ\x89)5\x09lg\xfb\xa9\xb2\xe1^\xe5\xe6%\xcd3\x81\xce\xbf\x9c\xad\xacc%\xcd\xd3\x96\x17\x9b\x11\xcb\xea.p\xba9\xa2.\xd7\xfa\x8f\xd4\x89\xc0 \xb0TI\xb8\xcd2C@L\xd7Q\xcd\xee\xc5[\x1a\xd5\x10@>\xe9\xbe\xd7\x86e`_\x04\xba\x04^U\x8c\xb2\xe1\x86\x95z7h\xe0F\x95\xfdR\x14\xdd\xfb!pB\xb3\xf3\xce\x11E\xc7.\xfe\xd5\xdf\xec\xa8\xb2\xbfU\x15\xacP\x04\x90\x90\x95\xf2op\x14\xaa\x9er\xf5\x08\x14\xca\x86\xb6\x1d]\x0d\x1f\xf7\x1a\x02\x1b\xf7J<Z\x81Bh\x02\xda\x90c\xbb\xbcVn\xf2h\xaf!\x10\xc5t\x95\xdd\x0f,\x84&\xe0(\xb2\xa2\xe8Lx~\x02 \xea0)\xdb\x05\xc7\xd4\xf9\x98\x11X,\x06f\xd2\xd6\x81.\xe0\x8c\xc0lh\x02\x85\xc0d\x05V\xcb\x861\x80\xf9\x1e7p\x84\x01\xe0CU\xb6\xf3\xc7zI\xc3\xc5b*Z\x9aZ+)\xdb\xbc\xbe450\x13\x9a@1\x15-i\x18\x11E*\xee\xf9#\x00\xb9^w\xbd\x10\x98\xb3\xc0mmX\x00|\xc0\xd7\x86\x85\x88p\xab\x10\x98s\xf9\xa4\xfb\x0d`\xfc\xebV\xda\xca?\xfc\xe6\xbc\xbb\xb5\xef,\x8e{~\xc66\x96\x91\xbd\xf8O\xad\x95T\xe7K\xff\x9em`c\x07n\xc7\xee\xecwi?\xd6\xf8@\x14\xa3\xc0\x1c\x90\xce'\xdd\xf75\x9aW\x97\x95\xbd?\x22dV6\x82\xfb\xbb\xb5\xe30\x03\xc9\xa0\x86\x87\xc0imX\x16\x85'\xb0f\x13\xe0\xa4}1\x1d\xc0\x17`8\x9ftg\xff\xcbH\xd6\x1cQ\x97E\xed\x8cdmU#\xd9[G\x91mj`\xe6@1?\xc2\x11\x0e\x1d~\x03\xf9\xaf!U\xd9\x8f\x13A\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xf9\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x07tIME\x07\xe1\x05\x0d\x0a:\x11i\xc8Nw\x00\x00\x00\x86IDATX\xc3c`\x18\xe9\x80\x11\x85\xf7\xff?\xa3\xed\xfaW\xffhi\xe1\xe1@1&\x06F\xc6\xff\x98\x0e\xa0\x83\xe5\xd8\x1c\x01w\x80\xed\xba\x97\xffQ\x14\x05\x893R\xd3R\x5c\xe63au!\x95-\xc7g&\x13=,\xc7g6\xd3@\xe7\x82Q\x07\x8c:\x80\x85\xd8|K\xb7l8\x9a\x06F\x1d0\xea\x80AS\x0e\xd0\xb2V\x1c\x8d\x82Q\x07\x0cn\x07P\xbb\x16$d6\x13=\xaab|f\x0e\x9e\x8e\x09\xdd\xbaft*\xe0\x86\x0e\x00\x00\x08^8e9\x12\x10\xc2\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x9e\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15\x0f\xfd\x8f\xf8.\x00\x00\x00\x22IDAT\x08\xd7c`\xc0\x0d\xfe\x9f\x87\xb1\x18\x91\x05\x18\x0d\xe1BH*\x0c\x19\x18\x18\x91\x05\x10*\xd1\x00\x00\xca\xb5\x07\xd2v\xbb\xb2\xc5\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xeb\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\x09pHYs\x00\x00\x0d\xd7\x00\x00\x0d\xd7\x01B(\x9bx\x00\x00\x00\x19tEXtSoftware\x00www.inkscape.org\x9b\xee<\x1a\x00\x00\x01hIDATX\x85\xed\x97MN\xc2@\x18\x86\x9f\xaf\x10\x14\xd4\x03\xa0W\x10\x13\xb6\x9eCv\xc8X\x8c&p\x1f11\xa1tH\x97x\x0c\xd7\xc4x\x07q\xef\x0f\x02\x91\xcf\x85\x94 \xa0,\x1c\x5ch\xdf\xddL\xdf\xf4y\xa6M\xd3\x19\xf8\xef\x91\xf9\xb1o\xcc\x09P\x03\x0a\xc0\xa6#\xce+p'\x22\x8d \x0c-\xa0\xcb\x04\xc47&\x04*\xc0\x00\xe8\x02O\x8e\x04\xb6\x81\x22\xb0\x01\xb4Z\xd6\x9e\xc6\x12S\x01\xdf\x18\x1f\x08\x04n\xd2oo\xa5\xab(\xea9\x82\x03p^.\xe7G\x9e\xd7A\xe4P\xc0\x04\xd6\xb6\x01\xbc\x99N\x0d\x18\x8cE\x8e\x5c\xc3\x01\xae\xa2\xa8'\xe9t\x09\x18\xaaH=\x9e\x9f\x15\xd8\x07\xbaa\x18>\xb8\x86\xc7\x09\x82\xe0\x1e\x91.\xaa\x85e\x02YT_\xd6\x05\x9ff<~\x06r\xf10\xbd\xaa\xef\x1b\xa3\xab:\xdf\xa5e\xed\xfc\x97\xf6)\xdew\x17\x7f#\x89@\x22\x90\x08$\x02\x89@\x22\x90\x08\xac\xdc\x0f\xac\xfa\x9f\xff4\xb3O\xa0\x8fH\xee\xcb\xa63\xa2\xb7\x05\xf4\x17\x04\x14\xee\x80\xe2y\xb9\x9c_\x17\xbbR\xa9\xec\xa1Z\x04n\x17\x04<\x91K`c\x94J]W\xab\xd5\xddu\xc0S\x22\x1d \xa3\x22\x8dx~\xfe`\xd2\x04|`8\xd9\xbd>:\xa1\x8b\xecLV\x9eQh\x86\xd6\x9e1\x7f0\x89\xabUc\x8eU\xa4\x8e\xea\x01\x90u\x22\xf0\xf1\xceoQ\xbdh\xb5\xdb\x91\xa3{\xfe\x91\xbc\x03\x16qj'Dt\xfeO\x00\x00\x00\x00IEND\xaeB`\x82"
qt_resource_name = b"\x00\x09\x09_\x97\x13\x00q\x00s\x00s\x00_\x00i\x00c\x00o\x00n\x00s\x00\x0a\x09$M%\x00q\x00d\x00a\x00r\x00k\x00s\x00t\x00y\x00l\x00e\x00\x09\x00(\xad#\x00s\x00t\x00y\x00l\x00e\x00.\x00q\x00s\x00s\x00\x02\x00\x00\x07\x83\x00r\x00c\x00\x11\x0a\xe5l\x07\x00r\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\x00n\x00g\x00\x09\x06\x98\x83'\x00c\x00l\x00o\x00s\x00e\x00.\x00p\x00n\x00g\x00\x11\x08\x8cj\xa7\x00H\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x1a\x01!\xebG\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\x00-\x00m\x00o\x00r\x00e\x00.\x00p\x00n\x00g\x00\x0a\x05\x95\xde'\x00u\x00n\x00d\x00o\x00c\x00k\x00.\x00p\x00n\x00g\x00\x13\x08\xc8\x96\xe7\x00r\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\x00n\x00g\x00\x15\x0f\xf3\xc0\x07\x00u\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x1f\x0a\xae'G\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x0f\x0c\xe2hg\x00t\x00r\x00a\x00n\x00s\x00p\x00a\x00r\x00e\x00n\x00t\x00.\x00p\x00n\x00g\x00\x16\x01u\xcc\x87\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\x00n\x00g\x00\x14\x0b\xc5\xd7\xc7\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00v\x00l\x00i\x00n\x00e\x00.\x00p\x00n\x00g\x00\x11\x08\x90\x94g\x00c\x00l\x00o\x00s\x00e\x00-\x00p\x00r\x00e\x00s\x00s\x00e\x00d\x00.\x00p\x00n\x00g\x00\x14\x07\xec\xd1\xc7\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\x00p\x00n\x00g\x00\x0e\x0e\xde\xfa\xc7\x00l\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x12\x07\x8f\x9d'\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00-\x00o\x00n\x00.\x00p\x00n\x00g\x00\x0f\x02\x9f\x05\x87\x00r\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x0e\x04\xa2\xfc\xa7\x00d\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x11\x08\xc4j\xa7\x00V\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x10\x01\x07J\xa7\x00V\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x19\x08>\xcc\x07\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\x00-\x00e\x00n\x00d\x00.\x00p\x00n\x00g\x00\x1c\x01\xe0J\x07\x00r\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x14\x06^,\x07\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00-\x00o\x00n\x00.\x00p\x00n\x00g\x00\x0f\x06S%\xa7\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00.\x00p\x00n\x00g\x00\x0c\x06A@\x87\x00s\x00i\x00z\x00e\x00g\x00r\x00i\x00p\x00.\x00p\x00n\x00g\x00\x10\x01\x00\xca\xa7\x00H\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x1c\x08?\xdag\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\x00\x0f\x01\xf4\x81G\x00c\x00l\x00o\x00s\x00e\x00-\x00h\x00o\x00v\x00e\x00r\x00.\x00p\x00n\x00g\x00\x18\x03\x8e\xdeg\x00r\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x1a\x0e\xbc\xc3g\x00r\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x17\x0c\xabQ\x07\x00d\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x11\x0b\xda0\xa7\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00.\x00p\x00n\x00g\x00\x1a\x01\x87\xaeg\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00i\x00n\x00d\x00e\x00t\x00e\x00r\x00m\x00i\x00n\x00a\x00t\x00e\x00.\x00p\x00n\x00g\x00\x17\x0ce\xce\x07\x00l\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x19\x0bYn\x87\x00r\x00a\x00d\x00i\x00o\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\x00\x1a\x05\x11\xe0\xe7\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\x00\x17\x0f\x1e\x9bG\x00r\x00a\x00d\x00i\x00o\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\x00 \x09\xd7\x1f\xa7\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00i\x00n\x00d\x00e\x00t\x00e\x00r\x00m\x00i\x00n\x00a\x00t\x00e\x00_\x00f\x00o\x00c\x00u\x00s\x00.\x00p\x00n\x00g\x00\x0c\x06\xe6\xe6g\x00u\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x1d\x09\x07\x81\x07\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g"
qt_resource_struct = b"\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x18\x00\x02\x00\x00\x00\x01\x00\x00\x00+\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00J\x00\x02\x00\x00\x00'\x00\x00\x00\x04\x00\x00\x04P\x00\x00\x00\x00\x00\x01\x00\x00\xd88\x00\x00\x03D\x00\x00\x00\x00\x00\x01\x00\x00\xc7o\x00\x00\x00\xbc\x00\x00\x00\x00\x00\x01\x00\x00\xa9\x98\x00\x00\x01\xd4\x00\x00\x00\x00\x00\x01\x00\x00\xb2\xb2\x00\x00\x05\xa4\x00\x00\x00\x00\x00\x01\x00\x00\xe2(\x00\x00\x03\xa2\x00\x00\x00\x00\x00\x01\x00\x00\xd3v\x00\x00\x04\xb4\x00\x00\x00\x00\x00\x01\x00\x00\xda\x0c\x00\x00\x02\xd6\x00\x00\x00\x00\x00\x01\x00\x00\xbb\x07\x00\x00\x04\xd8\x00\x00\x00\x00\x00\x01\x00\x00\xdcf\x00\x00\x02\xfa\x00\x00\x00\x00\x00\x01\x00\x00\xbb\xab\x00\x00\x06J\x00\x00\x00\x00\x00\x01\x00\x00\xe7M\x00\x00\x00\xf6\x00\x00\x00\x00\x00\x01\x00\x00\xaaR\x00\x00\x042\x00\x00\x00\x00\x00\x01\x00\x00\xd7\xb3\x00\x00\x04\x0e\x00\x00\x00\x00\x00\x01\x00\x00\xd7\x09\x00\x00\x03\xe0\x00\x00\x00\x00\x00\x01\x00\x00\xd6r\x00\x00\x00|\x00\x00\x00\x00\x00\x01\x00\x00\xa6\x9a\x00\x00\x06\xfe\x00\x00\x00\x00\x00\x01\x00\x00\xec\x9c\x00\x00\x02\xac\x00\x00\x00\x00\x00\x01\x00\x00\xbam\x00\x00\x02\x5c\x00\x00\x00\x00\x00\x01\x00\x00\xb7\xd3\x00\x00\x03j\x00\x00\x00\x00\x00\x01\x00\x00\xd2\x92\x00\x00\x04v\x00\x00\x00\x00\x00\x01\x00\x00\xd9\x18\x00\x00\x00\x94\x00\x00\x00\x00\x00\x01\x00\x00\xa8\xe8\x00\x00\x024\x00\x00\x00\x00\x00\x01\x00\x00\xb5y\x00\x00\x03\x1c\x00\x00\x00\x00\x00\x01\x00\x00\xbcT\x00\x00\x01\x10\x00\x00\x00\x00\x00\x01\x00\x00\xac\x98\x00\x00\x07\x1c\x00\x00\x00\x00\x00\x01\x00\x00\xed>\x00\x00\x06\xb8\x00\x00\x00\x00\x00\x01\x00\x00\xeb\x9f\x00\x00\x01l\x00\x00\x00\x00\x00\x01\x00\x00\xb0\x17\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00\xa2\xea\x00\x00\x06\x12\x00\x00\x00\x00\x00\x01\x00\x00\xe4\xc3\x00\x00\x02\x06\x00\x00\x00\x00\x00\x01\x00\x00\xb4\x86\x00\x00\x05|\x00\x00\x00\x00\x00\x01\x00\x00\xe1\x84\x00\x00\x05\xde\x00\x00\x00\x00\x00\x01\x00\x00\xe4\x19\x00\x00\x05H\x00\x00\x00\x00\x00\x01\x00\x00\xe0\xda\x00\x00\x01\xb0\x00\x00\x00\x00\x00\x01\x00\x00\xb1\xeb\x00\x00\x05\x0e\x00\x00\x00\x00\x00\x01\x00\x00\xdd\x0a\x00\x00\x02\x8a\x00\x00\x00\x00\x00\x01\x00\x00\xb9\xc3\x00\x00\x06\x84\x00\x00\x00\x00\x00\x01\x00\x00\xe8M\x00\x00\x01<\x00\x00\x00\x00\x00\x01\x00\x00\xaft\x00\x00\x002\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00"
def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
